@@ -157,6 +157,8 @@ type Dal interface {
 	DropTables(dst ...interface{}) errors.Error
 	// HasTable checks if table exists
 	HasTable(table interface{}) bool
+	// HasColumn checks if column exists
+	HasColumn(table interface{}, columnName string) bool
 	// RenameTable renames table name
 	RenameTable(oldName, newName string) errors.Error
 	// GetColumns returns table columns in database
@@ -174,17 +176,39 @@ type Dal interface {
 	// Begin create a new transaction
 	Begin() Transaction
 	// IsErrorNotFound returns true if error is record-not-found
-	IsErrorNotFound(err errors.Error) bool
+	IsErrorNotFound(err error) bool
 	// IsDuplicationError returns true if error is duplicate-error
-	IsDuplicationError(err errors.Error) bool
+	IsDuplicationError(err error) bool
 	// RawCursor (Deprecated) executes raw sql query and returns a database cursor.
 	RawCursor(query string, params ...interface{}) (*sql.Rows, errors.Error)
 }
 
+type LockTable struct {
+	Table     string
+	Tabler    Tabler
+	Exclusive bool
+}
+
+func (l *LockTable) TableName() string {
+	if l.Table != "" {
+		return l.Table
+	}
+	if l.Tabler != nil {
+		return l.Tabler.TableName()
+	}
+	panic("either Table or Tabler must be specified")
+}
+
+type LockTables []*LockTable
+
 type Transaction interface {
 	Dal
 	Rollback() errors.Error
 	Commit() errors.Error
+	// table: exclusive
+	LockTables(lockTables LockTables) errors.Error
+	UnlockTables() errors.Error
+	// End(err *errors.Error)
 }
 
 type Rows interface {
