@@ -42,16 +42,17 @@ func (CICDPipeline) TableName() string {
 
 // this is for the field `result` in table.cicd_pipelines and table.cicd_tasks
 const (
-	SUCCESS = "SUCCESS"
-	FAILURE = "FAILURE"
-	ABORT   = "ABORT"
-	MANUAL  = "MANUAL"
+	RESULT_SUCCESS = "SUCCESS"
+	RESULT_FAILURE = "FAILURE"
+	RESULT_ABORT   = "ABORT"
+	RESULT_MANUAL  = "MANUAL"
+	RESULT_SKIPPED = "SKIPPED"
 )
 
 // this is for the field `status` in table.cicd_pipelines and table.cicd_tasks
 const (
-	IN_PROGRESS = "IN_PROGRESS"
-	DONE        = "DONE"
+	STATUS_IN_PROGRESS = "IN_PROGRESS"
+	STATUS_DONE        = "DONE"
 )
 
 type ResultRule struct {
@@ -59,12 +60,13 @@ type ResultRule struct {
 	Failed  []string
 	Abort   []string
 	Manual  []string
+	Skipped []string
 	Default string
 }
-type StatusRule struct {
-	InProgress []string
-	Done       []string
-	Manual     []string
+type StatusRule[T comparable] struct {
+	InProgress []T
+	Done       []T
+	Manual     []T
 	Default    string
 }
 
@@ -72,42 +74,47 @@ type StatusRule struct {
 func GetResult(rule *ResultRule, input interface{}) string {
 	for _, suc := range rule.Success {
 		if suc == input {
-			return SUCCESS
+			return RESULT_SUCCESS
 		}
 	}
 	for _, fail := range rule.Failed {
 		if fail == input {
-			return FAILURE
+			return RESULT_FAILURE
 		}
 	}
 	for _, abort := range rule.Abort {
 		if abort == input {
-			return ABORT
+			return RESULT_ABORT
 		}
 	}
 	for _, manual := range rule.Manual {
 		if manual == input {
-			return MANUAL
+			return RESULT_MANUAL
+		}
+	}
+	for _, skipped := range rule.Skipped {
+		if skipped == input {
+			return RESULT_SKIPPED
 		}
 	}
 	return rule.Default
 }
 
 // GetStatus compare the input with rule for return the enmu value of status
-func GetStatus(rule *StatusRule, input interface{}) string {
+func GetStatus[T comparable](rule *StatusRule[T], input T) string {
 	for _, inp := range rule.InProgress {
 		if inp == input {
-			return IN_PROGRESS
+			return STATUS_IN_PROGRESS
 		}
 	}
 	for _, done := range rule.Done {
 		if done == input {
-			return DONE
+			return STATUS_DONE
 		}
 	}
 	for _, manual := range rule.Manual {
 		if manual == input {
-			return MANUAL
+			return RESULT_MANUAL
 		}
 	}
 	return rule.Default
