@@ -27,7 +27,7 @@ type CiCDPipelineCommit struct {
 	CommitSha  string `gorm:"primaryKey;type:varchar(255)"`
 	Branch     string `gorm:"type:varchar(255)"`
 	RepoId     string `gorm:"index;type:varchar(255)"`
-	Repo       string
+	RepoUrl    string
 }
 
 func (CiCDPipelineCommit) TableName() string {
