@@ -136,22 +136,23 @@ var _ dal.Dal = (*Dalgorm)(nil)
 
 // Exec executes raw sql query
 func (d *Dalgorm) Exec(query string, params ...interface{}) errors.Error {
-	return errors.Convert(d.db.Exec(query, transformParams(params)...).Error)
+	return d.convertGormError(d.db.Exec(query, transformParams(params)...).Error)
 }
 
 // AutoMigrate runs auto migration for given models
 func (d *Dalgorm) AutoMigrate(entity interface{}, clauses ...dal.Clause) errors.Error {
-	err := errors.Convert(buildTx(d.db, clauses).AutoMigrate(entity))
+	err := buildTx(d.db, clauses).AutoMigrate(entity)
 	if err == nil {
 		// fix pg cache plan error
 		_ = d.First(entity, clauses...)
 	}
-	return err
+	return d.convertGormError(err)
 }
 
 // Cursor returns a database cursor, cursor is especially useful when handling big amount of rows of data
 func (d *Dalgorm) Cursor(clauses ...dal.Clause) (dal.Rows, errors.Error) {
-	return errors.Convert01(buildTx(d.db, clauses).Rows())
+	rows, err := buildTx(d.db, clauses).Rows()
+	return rows, d.convertGormError(err)
 }
 
 // CursorTx FIXME ...
@@ -162,7 +163,7 @@ func (d *Dalgorm) CursorTx(clauses ...dal.Clause) *gorm.DB {
 // Fetch loads row data from `cursor` into `dst`
 func (d *Dalgorm) Fetch(cursor dal.Rows, dst interface{}) errors.Error {
 	if rows, ok := cursor.(*sql.Rows); ok {
-		return errors.Convert(d.db.ScanRows(rows, dst))
+		return d.convertGormError(d.db.ScanRows(rows, dst))
 	} else {
 		return errors.Default.New(fmt.Sprintf("can not support type %s to be a dal.Rows interface", reflect.TypeOf(cursor).String()))
 	}
@@ -170,12 +171,12 @@ func (d *Dalgorm) Fetch(cursor dal.Rows, dst interface{}) errors.Error {
 
 // All loads matched rows from database to `dst`, USE IT WITH COUTIOUS!!
 func (d *Dalgorm) All(dst interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Find(dst).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Find(dst).Error)
 }
 
 // First loads first matched row from database to `dst`, error will be returned if no records were found
 func (d *Dalgorm) First(dst interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).First(dst).Error)
+	return d.convertGormError(buildTx(d.db, clauses).First(dst).Error)
 }
 
 // Count total records
@@ -187,37 +188,37 @@ func (d *Dalgorm) Count(clauses ...dal.Clause) (int64, errors.Error) {
 
 // Pluck used to query single column
 func (d *Dalgorm) Pluck(column string, dest interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Pluck(column, dest).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Pluck(column, dest).Error)
 }
 
 // Create insert record to database
 func (d *Dalgorm) Create(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Create(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Create(entity).Error)
 }
 
 // CreateWithMap insert record to database
 func (d *Dalgorm) CreateWithMap(entity interface{}, record map[string]interface{}) errors.Error {
-	return errors.Convert(buildTx(d.db, nil).Model(entity).Clauses(clause.OnConflict{UpdateAll: true}).Create(record).Error)
+	return d.convertGormError(buildTx(d.db, nil).Model(entity).Clauses(clause.OnConflict{UpdateAll: true}).Create(record).Error)
 }
 
 // Update updates record
 func (d *Dalgorm) Update(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Save(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Save(entity).Error)
 }
 
 // CreateOrUpdate tries to create the record, or fallback to update all if failed
 func (d *Dalgorm) CreateOrUpdate(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Clauses(clause.OnConflict{UpdateAll: true}).Create(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Clauses(clause.OnConflict{UpdateAll: true}).Create(entity).Error)
 }
 
 // CreateIfNotExist tries to create the record if not exist
 func (d *Dalgorm) CreateIfNotExist(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Clauses(clause.OnConflict{DoNothing: true}).Create(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Clauses(clause.OnConflict{DoNothing: true}).Create(entity).Error)
 }
 
 // Delete records from database
 func (d *Dalgorm) Delete(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).Delete(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Delete(entity).Error)
 }
 
 // UpdateColumn allows you to update mulitple records
@@ -226,7 +227,7 @@ func (d *Dalgorm) UpdateColumn(entityOrTable interface{}, columnName string, val
 		value = gorm.Expr(expr.Expr, transformParams(expr.Params)...)
 	}
 	clauses = append(clauses, dal.From(entityOrTable))
-	return errors.Convert(buildTx(d.db, clauses).Update(columnName, value).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Update(columnName, value).Error)
 }
 
 // UpdateColumns allows you to update multiple columns of mulitple records
@@ -241,19 +242,19 @@ func (d *Dalgorm) UpdateColumns(entityOrTable interface{}, set []dal.DalSet, cla
 	}
 
 	clauses = append(clauses, dal.From(entityOrTable))
-	return errors.Convert(buildTx(d.db, clauses).Updates(updatesSet).Error)
+	return d.convertGormError(buildTx(d.db, clauses).Updates(updatesSet).Error)
 }
 
 // UpdateAllColumn updated all Columns of entity
 func (d *Dalgorm) UpdateAllColumn(entity interface{}, clauses ...dal.Clause) errors.Error {
-	return errors.Convert(buildTx(d.db, clauses).UpdateColumns(entity).Error)
+	return d.convertGormError(buildTx(d.db, clauses).UpdateColumns(entity).Error)
 }
 
 // GetColumns FIXME ...
 func (d *Dalgorm) GetColumns(dst dal.Tabler, filter func(columnMeta dal.ColumnMeta) bool) (cms []dal.ColumnMeta, _ errors.Error) {
 	columnTypes, err := d.db.Migrator().ColumnTypes(dst.TableName())
 	if err != nil {
-		return nil, errors.Convert(err)
+		return nil, d.convertGormError(err)
 	}
 	for _, columnType := range columnTypes {
 		if filter == nil {
@@ -262,7 +263,7 @@ func (d *Dalgorm) GetColumns(dst dal.Tabler, filter func(columnMeta dal.ColumnMe
 			cms = append(cms, columnType)
 		}
 	}
-	return errors.Convert01(cms, nil)
+	return cms, nil
 }
 
 // AddColumn add one column for the table
@@ -286,7 +287,7 @@ func (d *Dalgorm) DropColumns(table string, columnNames ...string) errors.Error
 		err := d.Exec("ALTER TABLE ? DROP COLUMN ?", clause.Table{Name: table}, clause.Column{Name: columnName})
 		// err := d.db.Migrator().DropColumn(table, columnName)
 		if err != nil {
-			return errors.Convert(err)
+			return d.convertGormError(err)
 		}
 	}
 	return nil
@@ -325,7 +326,7 @@ func (d *Dalgorm) AllTables() ([]string, errors.Error) {
 	var tables []string
 	err := d.db.Raw(tableSql).Scan(&tables).Error
 	if err != nil {
-		return nil, errors.Convert(err)
+		return nil, d.convertGormError(err)
 	}
 	var filteredTables []string
 	for _, table := range tables {
@@ -338,7 +339,7 @@ func (d *Dalgorm) AllTables() ([]string, errors.Error) {
 
 // DropTables drop multiple tables by Model Pointer or Table Name
 func (d *Dalgorm) DropTables(dst ...interface{}) errors.Error {
-	return errors.Convert(d.db.Migrator().DropTable(dst...))
+	return d.convertGormError(d.db.Migrator().DropTable(dst...))
 }
 
 // HasTable checks if table exists
@@ -346,9 +347,32 @@ func (d *Dalgorm) HasTable(table interface{}) bool {
 	return d.db.Migrator().HasTable(table)
 }
 
+// HasColumn checks if column exists
+func (d *Dalgorm) HasColumn(table interface{}, columnName string) bool {
+	migrator := d.db.Migrator()
+	// Workaround in case table is a string
+	// which cause migrator.HasColumn to panic
+	// see: https://github.com/go-gorm/gorm/issues/5809
+	_, isString := table.(string)
+	if isString {
+		columnTypes, err := migrator.ColumnTypes(table)
+		if err != nil {
+			return false
+		}
+		for _, columnType := range columnTypes {
+			if columnType.Name() == columnName {
+				return true
+			}
+		}
+		return false
+	}
+	return migrator.HasColumn(table, columnName)
+}
+
 // RenameTable renames table name
 func (d *Dalgorm) RenameTable(oldName, newName string) errors.Error {
-	return errors.Convert(d.db.Migrator().RenameTable(oldName, newName))
+	err := d.db.Migrator().RenameTable(oldName, newName)
+	return d.convertGormError(err)
 }
 
 // DropIndexes drops indexes for specified table
@@ -356,7 +380,7 @@ func (d *Dalgorm) DropIndexes(table string, indexNames ...string) errors.Error {
 	for _, indexName := range indexNames {
 		err := d.db.Migrator().DropIndex(table, indexName)
 		if err != nil {
-			return errors.Convert(err)
+			return d.convertGormError(err)
 		}
 	}
 	return nil
@@ -382,21 +406,62 @@ func (d *Dalgorm) Begin() dal.Transaction {
 }
 
 // IsErrorNotFound checking if the sql error is not found.
-func (d *Dalgorm) IsErrorNotFound(err errors.Error) bool {
+func (d *Dalgorm) IsErrorNotFound(err error) bool {
 	return errors.Is(err, gorm.ErrRecordNotFound)
 }
 
 // IsDuplicationError checking if the sql error is not found.
-func (d *Dalgorm) IsDuplicationError(err errors.Error) bool {
+func (d *Dalgorm) IsDuplicationError(err error) bool {
 	return strings.Contains(strings.ToLower(err.Error()), "duplicate")
 }
 
+// IsCachedPlanError checks if the error is related to postgres cached query plan
+// This error occurs occasionally in Postgres when reusing a cached query
+// plan. It can be safely ignored since it does not actually affect results.
+func (d *Dalgorm) IsCachedPlanError(err error) bool {
+	return strings.Contains(strings.ToLower(err.Error()), "cached plan must not change result type")
+}
+
+// IsJsonOrderError checks if the error is related to postgres json ordering
+func (d *Dalgorm) IsJsonOrderError(err error) bool {
+	return strings.Contains(err.Error(), "identify an ordering operator for type json")
+}
+
+// IsTableExist checks if table exists
+func (d *Dalgorm) IsTableExist(err error) bool {
+	return strings.Contains(err.Error(), "Unknown table")
+}
+
 // RawCursor (Deprecated) executes raw sql query and returns a database cursor
 func (d *Dalgorm) RawCursor(query string, params ...interface{}) (*sql.Rows, errors.Error) {
-	return errors.Convert01(d.db.Raw(query, params...).Rows())
+	rows, err := d.db.Raw(query, params...).Rows()
+	return rows, d.convertGormError(err)
 }
 
 // NewDalgorm creates a *Dalgorm
 func NewDalgorm(db *gorm.DB) *Dalgorm {
 	return &Dalgorm{db}
 }
+
+func (d *Dalgorm) convertGormError(err error) errors.Error {
+	if err == nil {
+		return nil
+	}
+	if d.IsErrorNotFound(err) {
+		return errors.NotFound.WrapRaw(err)
+	}
+	if d.IsDuplicationError(err) {
+		return errors.BadInput.WrapRaw(err)
+	}
+	if d.IsJsonOrderError(err) {
+		return errors.BadInput.WrapRaw(err)
+	}
+	if d.IsCachedPlanError(err) {
+		return nil
+	}
+	if d.IsTableExist(err) {
+		return errors.BadInput.WrapRaw(err)
+	}
+
+	return errors.Internal.WrapRaw(err)
+}
