@@ -19,12 +19,12 @@ package api
 
 import (
 	"fmt"
+
 	"github.com/apache/incubator-devlake/plugins/bamboo/models"
 
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/utils"
 
-	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/devops"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/didgen"
 	plugin "github.com/apache/incubator-devlake/core/plugin"
@@ -64,14 +64,14 @@ func makeScopeV200(connectionId uint64, scopes []*plugin.BlueprintScopeV200) ([]
 		id := didgen.NewDomainIdGenerator(&models.BambooProject{}).Generate(connectionId, scope.Id)
 
 		// get project from db
-		BambooProject, err := GetProjectByConnectionIdAndscopeId(connectionId, scope.Id)
+		project, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connectionId, scope.Id)
 		if err != nil {
 			return nil, err
 		}
 
 		// add cicd_scope to scopes
-		if utils.StringsContains(scope.Entities, plugin.DOMAIN_TYPE_CICD) {
-			scopeCICD := devops.NewCicdScope(id, BambooProject.Name)
+		if utils.StringsContains(scopeConfig.Entities, plugin.DOMAIN_TYPE_CICD) {
+			scopeCICD := devops.NewCicdScope(id, project.Name)
 
 			sc = append(sc, scopeCICD)
 		}
@@ -90,13 +90,7 @@ func makePipelinePlanV200(
 		var stage plugin.PipelineStage
 		var err errors.Error
 		// get project
-		project, err := GetProjectByConnectionIdAndscopeId(connection.ID, scope.Id)
-		if err != nil {
-			return nil, err
-		}
-
-		// get transformationRuleId
-		transformationRules, err := GetTransformationRuleByproject(project)
+		_, scopeConfig, err := scopeHelper.DbHelper().GetScopeAndConfig(connection.ID, scope.Id)
 		if err != nil {
 			return nil, err
 		}
@@ -105,10 +99,10 @@ func makePipelinePlanV200(
 		options := make(map[string]interface{})
 		options["connectionId"] = connection.ID
 		options["projectKey"] = scope.Id
-		options["transformationRuleId"] = transformationRules.ID
+		options["scopeConfigId"] = scopeConfig.ID
 
 		// construct subtasks
-		subtasks, err := helper.MakePipelinePlanSubtasks(subtaskMetas, scope.Entities)
+		subtasks, err := helper.MakePipelinePlanSubtasks(subtaskMetas, scopeConfig.Entities)
 		if err != nil {
 			return nil, err
 		}
@@ -123,39 +117,3 @@ func makePipelinePlanV200(
 	}
 	return plans, nil
 }
-
-// GetProjectByConnectionIdAndscopeId get tbe project by the connectionId and the scopeId
-func GetProjectByConnectionIdAndscopeId(connectionId uint64, scopeId string) (*models.BambooProject, errors.Error) {
-	key := scopeId
-	project := &models.BambooProject{}
-	db := basicRes.GetDal()
-	err := db.First(project, dal.Where("connection_id = ? AND project_key = ?", connectionId, key))
-	if err != nil {
-		if db.IsErrorNotFound(err) {
-			return nil, errors.Default.Wrap(err, fmt.Sprintf("can not find project by connection [%d] scope [%s]", connectionId, scopeId))
-		}
-		return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find project by connection [%d] scope [%s]", connectionId, scopeId))
-	}
-
-	return project, nil
-}
-
-// GetTransformationRuleByproject get the GetTransformationRule by project
-func GetTransformationRuleByproject(project *models.BambooProject) (*models.BambooTransformationRule, errors.Error) {
-	transformationRules := &models.BambooTransformationRule{}
-	transformationRuleId := project.TransformationRuleId
-	if transformationRuleId != 0 {
-		db := basicRes.GetDal()
-		err := db.First(transformationRules, dal.Where("id = ?", transformationRuleId))
-		if err != nil {
-			if db.IsErrorNotFound(err) {
-				return nil, errors.Default.Wrap(err, fmt.Sprintf("can not find transformationRules by transformationRuleId [%d]", transformationRuleId))
-			}
-			return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find transformationRules by transformationRuleId [%d]", transformationRuleId))
-		}
-	} else {
-		transformationRules.ID = 0
-	}
-
-	return transformationRules, nil
-}
