@@ -38,7 +38,7 @@ func TestBambooPlanBuildDataFlow(t *testing.T) {
 		Options: &models.BambooOptions{
 			ConnectionId: 3,
 			ProjectKey:   "TEST1",
-			BambooTransformationRule: &models.BambooTransformationRule{
+			BambooScopeConfig: &models.BambooScopeConfig{
 				DeploymentPattern: "(?i)compile",
 				ProductionPattern: "(?i)compile",
 			},
