@@ -39,7 +39,6 @@ var _ interface {
 	plugin.PluginTask
 	plugin.PluginModel
 	plugin.PluginMigration
-	plugin.PluginBlueprintV100
 	plugin.DataSourcePluginBlueprintV200
 	plugin.CloseablePluginTask
 	plugin.PluginSource
@@ -48,20 +47,21 @@ var _ interface {
 type Bamboo struct{}
 
 func (p Bamboo) Init(br context.BasicRes) errors.Error {
-	api.Init(br)
+	api.Init(br, p)
+
 	return nil
 }
 
-func (p Bamboo) Connection() interface{} {
+func (p Bamboo) Connection() dal.Tabler {
 	return &models.BambooConnection{}
 }
 
-func (p Bamboo) Scope() interface{} {
-	return nil
+func (p Bamboo) Scope() plugin.ToolLayerScope {
+	return &models.BambooProject{}
 }
 
-func (p Bamboo) TransformationRule() interface{} {
-	return nil
+func (p Bamboo) ScopeConfig() dal.Tabler {
+	return &models.BambooScopeConfig{}
 }
 
 func (p Bamboo) MakeDataSourcePipelinePlanV200(connectionId uint64, scopes []*plugin.BlueprintScopeV200, syncPolicy plugin.BlueprintSyncPolicy) (plugin.PipelinePlan, []plugin.Scope, errors.Error) {
@@ -77,6 +77,9 @@ func (p Bamboo) GetTablesInfo() []dal.Tabler {
 		&models.BambooPlanBuild{},
 		&models.BambooPlanBuildVcsRevision{},
 		&models.BambooJobBuild{},
+		&models.BambooDeployBuild{},
+		&models.BambooDeployEnvironment{},
+		&models.BambooScopeConfig{},
 	}
 }
 
@@ -84,6 +87,10 @@ func (p Bamboo) Description() string {
 	return "collect some Bamboo data"
 }
 
+func (p Bamboo) Name() string {
+	return "bamboo"
+}
+
 func (p Bamboo) SubTaskMetas() []plugin.SubTaskMeta {
 	// TODO add your sub task here
 	return []plugin.SubTaskMeta{
@@ -119,6 +126,7 @@ func (p Bamboo) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]i
 	connectionHelper := helper.NewConnectionHelper(
 		taskCtx,
 		nil,
+		p.Name(),
 	)
 	connection := &models.BambooConnection{}
 	err = connectionHelper.FirstById(connection, op.ConnectionId)
@@ -150,26 +158,26 @@ func (p Bamboo) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]i
 				return nil, err
 			}
 		}
-		op.TransformationRuleId = scope.TransformationRuleId
+		op.ScopeConfigId = scope.ScopeConfigId
 		if err != nil {
 			return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find project: %s", op.ProjectKey))
 		}
 	}
 
-	if op.BambooTransformationRule == nil && op.TransformationRuleId != 0 {
-		var transformationRule models.BambooTransformationRule
+	if op.BambooScopeConfig == nil && op.ScopeConfigId != 0 {
+		var scopeConfig models.BambooScopeConfig
 		db := taskCtx.GetDal()
-		err = db.First(&transformationRule, dal.Where("id = ?", op.TransformationRuleId))
+		err = db.First(&scopeConfig, dal.Where("id = ?", op.ScopeConfigId))
 		if err != nil {
 			if db.IsErrorNotFound(err) {
-				return nil, errors.Default.Wrap(err, fmt.Sprintf("can not find transformationRules by transformationRuleId [%d]", op.TransformationRuleId))
+				return nil, errors.Default.Wrap(err, fmt.Sprintf("can not find scopeConfig by scopeConfigId [%d]", op.ScopeConfigId))
 			}
-			return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find transformationRules by transformationRuleId [%d]", op.TransformationRuleId))
+			return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find scopeConfig by scopeConfigId [%d]", op.ScopeConfigId))
 		}
-		op.BambooTransformationRule = &transformationRule
+		op.BambooScopeConfig = &scopeConfig
 	}
-	if op.BambooTransformationRule == nil && op.TransformationRuleId == 0 {
-		op.BambooTransformationRule = new(models.BambooTransformationRule)
+	if op.BambooScopeConfig == nil && op.ScopeConfigId == 0 {
+		op.BambooScopeConfig = new(models.BambooScopeConfig)
 	}
 	regexEnricher := helper.NewRegexEnricher()
 	if err := regexEnricher.TryAdd(devops.DEPLOYMENT, op.DeploymentPattern); err != nil {
@@ -208,13 +216,14 @@ func (p Bamboo) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"PATCH":  api.PatchConnection,
 			"DELETE": api.DeleteConnection,
 		},
-		"connections/:connectionId/transformation_rules": {
-			"POST": api.CreateTransformationRule,
-			"GET":  api.GetTransformationRuleList,
+		"connections/:connectionId/scope-configs": {
+			"POST": api.CreateScopeConfig,
+			"GET":  api.GetScopeConfigList,
 		},
-		"connections/:connectionId/transformation_rules/:id": {
-			"PATCH": api.UpdateTransformationRule,
-			"GET":   api.GetTransformationRule,
+		"connections/:connectionId/scope-configs/:id": {
+			"PATCH":  api.UpdateScopeConfig,
+			"GET":    api.GetScopeConfig,
+			"DELETE": api.DeleteScopeConfig,
 		},
 		"connections/:connectionId/scopes": {
 			"GET": api.GetScopeList,
@@ -227,16 +236,13 @@ func (p Bamboo) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"GET": api.SearchRemoteScopes,
 		},
 		"connections/:connectionId/scopes/:scopeId": {
-			"GET":   api.GetScope,
-			"PATCH": api.UpdateScope,
+			"GET":    api.GetScope,
+			"PATCH":  api.UpdateScope,
+			"DELETE": api.DeleteScope,
 		},
 	}
 }
 
-func (p Bamboo) MakePipelinePlan(connectionId uint64, scope []*plugin.BlueprintScopeV100) (plugin.PipelinePlan, errors.Error) {
-	return nil, errors.Default.New("Bamboo does not support blueprint v100")
-}
-
 func (p Bamboo) Close(taskCtx plugin.TaskContext) errors.Error {
 	data, ok := taskCtx.GetData().(*tasks.BambooTaskData)
 	if !ok {
