@@ -27,5 +27,7 @@ func All() []plugin.MigrationScript {
 		new(addInitTables),
 		new(addConnectionIdToTransformationRule),
 		new(addTypeAndEnvironment),
+		new(renameTr2ScopeConfig),
+		new(addRawParamTableForScope),
 	}
 }
