@@ -73,9 +73,9 @@ func ConvertJobBuilds(taskCtx plugin.SubTaskContext) errors.Error {
 					Default: "",
 				}, line.BuildState),
 
-				Status: devops.GetStatus(&devops.StatusRule{
+				Status: devops.GetStatus(&devops.StatusRule[string]{
 					Done:    []string{"Finished"},
-					Default: devops.IN_PROGRESS,
+					Default: devops.STATUS_IN_PROGRESS,
 				}, line.LifeCycleState),
 			}
 
