@@ -36,5 +36,7 @@ func All() []plugin.MigrationScript {
 		new(addRepoIdField20230411),
 		new(addRepoIdToPr),
 		new(addBitbucketCommitAuthorInfo),
+		new(renameTr2ScopeConfig),
+		new(addRawParamTableForScope),
 	}
 }
