@@ -38,5 +38,10 @@ func All() []plugin.MigrationScript {
 		new(addEnvToRunAndJob),
 		new(addGithubCommitAuthorInfo),
 		new(fixRunNameToText),
+		new(addGithubMultiAuth),
+		new(renameTr2ScopeConfig),
+		new(addGithubIssueAssignee),
+		new(addFullName),
+		new(addRawParamTableForScope),
 	}
 }
