@@ -29,15 +29,14 @@ import (
 )
 
 type GithubOptions struct {
-	ConnectionId                     uint64   `json:"connectionId" mapstructure:"connectionId,omitempty"`
-	TransformationRuleId             uint64   `json:"transformationRuleId" mapstructure:"transformationRuleId,omitempty"`
-	GithubId                         int      `json:"githubId" mapstructure:"githubId,omitempty"`
-	Tasks                            []string `json:"tasks,omitempty" mapstructure:",omitempty"`
-	TimeAfter                        string   `json:"timeAfter" mapstructure:"timeAfter,omitempty"`
-	Owner                            string   `json:"owner" mapstructure:"owner,omitempty"`
-	Repo                             string   `json:"repo"  mapstructure:"repo,omitempty"`
-	Name                             string   `json:"name"  mapstructure:"name,omitempty"`
-	*models.GithubTransformationRule `mapstructure:"transformationRules,omitempty" json:"transformationRules"`
+	ConnectionId  uint64                    `json:"connectionId" mapstructure:"connectionId,omitempty"`
+	ScopeConfigId uint64                    `json:"scopeConfigId" mapstructure:"scopeConfigId,omitempty"`
+	GithubId      int                       `json:"githubId" mapstructure:"githubId,omitempty"`
+	TimeAfter     string                    `json:"timeAfter" mapstructure:"timeAfter,omitempty"`
+	Owner         string                    `json:"owner" mapstructure:"owner,omitempty"`
+	Repo          string                    `json:"repo"  mapstructure:"repo,omitempty"`
+	Name          string                    `json:"name"  mapstructure:"name,omitempty"`
+	ScopeConfig   *models.GithubScopeConfig `mapstructure:"scopeConfig,omitempty" json:"scopeConfig"`
 }
 
 type GithubTaskData struct {
@@ -48,10 +47,8 @@ type GithubTaskData struct {
 	RegexEnricher *helper.RegexEnricher
 }
 
-type GithubApiParams struct {
-	ConnectionId uint64
-	Name         string
-}
+// TODO: avoid touching too many files, should be removed in the future
+type GithubApiParams models.GithubApiParams
 
 func DecodeAndValidateTaskOptions(options map[string]interface{}) (*GithubOptions, errors.Error) {
 	op, err := DecodeTaskOptions(options)
