@@ -39,9 +39,9 @@ func TestGitlabPipelineDataFlow(t *testing.T) {
 
 	taskData := &tasks.GitlabTaskData{
 		Options: &tasks.GitlabOptions{
-			ConnectionId:             1,
-			ProjectId:                12345678,
-			GitlabTransformationRule: new(models.GitlabTransformationRule),
+			ConnectionId: 1,
+			ProjectId:    12345678,
+			ScopeConfig:  new(models.GitlabScopeConfig),
 		},
 		RegexEnricher: regexEnricher,
 	}
