@@ -35,6 +35,9 @@ func All() []plugin.MigrationScript {
 		new(addConnectionIdToTransformationRule),
 		new(addGitlabCommitAuthorInfo),
 		new(addTypeEnvToPipeline),
+		new(renameTr2ScopeConfig),
+		new(addGitlabIssueAssignee),
 		new(addMrCommitSha),
+		new(addRawParamTableForScope),
 	}
 }
