@@ -31,7 +31,7 @@ var _ plugin.ToolLayerScope = (*GitlabProject)(nil)
 
 type GitlabProject struct {
 	ConnectionId            uint64 `json:"connectionId" mapstructure:"connectionId" validate:"required" gorm:"primaryKey"`
-	TransformationRuleId    uint64 `json:"transformationRuleId,omitempty" mapstructure:"transformationRuleId"`
+	ScopeConfigId           uint64 `json:"scopeConfigId,omitempty" mapstructure:"scopeConfigId"`
 	GitlabId                int    `json:"gitlabId" mapstructure:"gitlabId" validate:"required" gorm:"primaryKey"`
 	Name                    string `json:"name" mapstructure:"name" gorm:"type:varchar(255)"`
 	Description             string `json:"description" mapstructure:"description"`
@@ -63,6 +63,17 @@ func (p GitlabProject) ScopeName() string {
 	return p.Name
 }
 
+func (p GitlabProject) ScopeFullName() string {
+	return p.PathWithNamespace
+}
+
+func (p GitlabProject) ScopeParams() interface{} {
+	return &GitlabApiParams{
+		ConnectionId: p.ConnectionId,
+		ProjectId:    p.GitlabId,
+	}
+}
+
 // Convert the API response to our DB model instance
 func (gitlabApiProject GitlabApiProject) ConvertApiScope() plugin.ToolLayerScope {
 	p := &GitlabProject{}
@@ -125,3 +136,8 @@ func (p GroupResponse) GroupId() string {
 func (p GroupResponse) GroupName() string {
 	return p.Name
 }
+
+type GitlabApiParams struct {
+	ConnectionId uint64
+	ProjectId    int
+}
