@@ -23,6 +23,10 @@ import (
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
+func init() {
+	RegisterSubtaskMeta(&CollectApiCommitsMeta)
+}
+
 const RAW_COMMIT_TABLE = "gitlab_api_commit"
 
 var CollectApiCommitsMeta = plugin.SubTaskMeta{
@@ -31,6 +35,7 @@ var CollectApiCommitsMeta = plugin.SubTaskMeta{
 	EnabledByDefault: false,
 	Description:      "Collect commit data from gitlab api, does not support either timeFilter or diffSync.",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CODE},
+	Dependencies:     []*plugin.SubTaskMeta{&ConvertJobMeta},
 }
 
 type GitlabApiCommit struct {
