@@ -25,12 +25,17 @@ import (
 	"github.com/apache/incubator-devlake/plugins/gitlab/models"
 )
 
+func init() {
+	RegisterSubtaskMeta(&ExtractApiMrCommitsMeta)
+}
+
 var ExtractApiMrCommitsMeta = plugin.SubTaskMeta{
 	Name:             "extractApiMergeRequestsCommits",
 	EntryPoint:       ExtractApiMergeRequestsCommits,
 	EnabledByDefault: true,
 	Description:      "Extract raw merge requests commit data into tool layer table GitlabMrCommit and GitlabCommit",
 	DomainTypes:      []string{plugin.DOMAIN_TYPE_CODE_REVIEW},
+	Dependencies:     []*plugin.SubTaskMeta{&CollectApiMrCommitsMeta},
 }
 
 func ExtractApiMergeRequestsCommits(taskCtx plugin.SubTaskContext) errors.Error {
