@@ -29,16 +29,12 @@ import (
 
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
+	"github.com/apache/incubator-devlake/plugins/gitlab/models"
 
 	"github.com/apache/incubator-devlake/core/plugin"
 	helper "github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 )
 
-type GitlabApiParams struct {
-	ConnectionId uint64
-	ProjectId    int
-}
-
 type GitlabInput struct {
 	GitlabId int
 	Iid      int
@@ -141,7 +137,7 @@ func CreateRawDataSubTaskArgs(taskCtx plugin.SubTaskContext, Table string) (*hel
 	data := taskCtx.GetData().(*GitlabTaskData)
 	RawDataSubTaskArgs := &helper.RawDataSubTaskArgs{
 		Ctx: taskCtx,
-		Params: GitlabApiParams{
+		Params: models.GitlabApiParams{
 			ProjectId:    data.Options.ProjectId,
 			ConnectionId: data.Options.ConnectionId,
 		},
