@@ -20,6 +20,7 @@ package e2e
 import (
 	"testing"
 
+	"github.com/apache/incubator-devlake/core/models/common"
 	"github.com/apache/incubator-devlake/core/models/domainlayer/ticket"
 	"github.com/apache/incubator-devlake/helpers/e2ehelper"
 	"github.com/apache/incubator-devlake/plugins/jira/impl"
@@ -35,7 +36,7 @@ func TestIssueDataFlow(t *testing.T) {
 		Options: &tasks.JiraOptions{
 			ConnectionId: 2,
 			BoardId:      8,
-			TransformationRules: &tasks.JiraTransformationRule{
+			ScopeConfig: &tasks.JiraScopeConfig{
 				StoryPointField: "customfield_10024",
 				TypeMappings: map[string]tasks.TypeMapping{
 					"子任务": {
@@ -66,6 +67,7 @@ func TestIssueDataFlow(t *testing.T) {
 	dataflowTester.FlushTabler(&models.JiraIssue{})
 	dataflowTester.FlushTabler(&models.JiraBoardIssue{})
 	dataflowTester.FlushTabler(&models.JiraSprintIssue{})
+	dataflowTester.FlushTabler(&models.JiraIssueComment{})
 	dataflowTester.FlushTabler(&models.JiraIssueChangelogs{})
 	dataflowTester.FlushTabler(&models.JiraIssueChangelogItems{})
 	dataflowTester.FlushTabler(&models.JiraWorklog{})
@@ -102,6 +104,7 @@ func TestIssueDataFlow(t *testing.T) {
 			"self",
 			"issue_key",
 			"summary",
+			"description",
 			"type",
 			"epic_key",
 			"status_name",
@@ -131,6 +134,7 @@ func TestIssueDataFlow(t *testing.T) {
 			"std_status",
 			"icon_url",
 			"changelog_total",
+			"comment_total",
 		),
 	)
 
@@ -197,6 +201,7 @@ func TestIssueDataFlow(t *testing.T) {
 	// verify issue conversion
 	dataflowTester.FlushTabler(&ticket.Issue{})
 	dataflowTester.FlushTabler(&ticket.BoardIssue{})
+	dataflowTester.FlushTabler(&ticket.IssueAssignee{})
 	dataflowTester.Subtask(tasks.ConvertIssuesMeta, taskData)
 	dataflowTester.VerifyTable(
 		ticket.Issue{},
@@ -237,4 +242,8 @@ func TestIssueDataFlow(t *testing.T) {
 		"./snapshot_tables/board_issues.csv",
 		[]string{"board_id", "issue_id"},
 	)
+	dataflowTester.VerifyTableWithOptions(ticket.IssueAssignee{}, e2ehelper.TableOptions{
+		CSVRelPath:  "./snapshot_tables/issue_assignees.csv",
+		IgnoreTypes: []interface{}{common.NoPKModel{}},
+	})
 }
