@@ -36,7 +36,11 @@ func All() []plugin.MigrationScript {
 		new(addConnectionIdToTransformationRule),
 		new(addChangeTotal20230412),
 		new(expandRemotelinkSelfUrl),
+		new(addDescAndComments),
+		new(renameTr2ScopeConfig),
 		new(addRepoUrl),
 		new(addApplicationType),
+		new(clearRepoPattern),
+		new(addRawParamTableForScope),
 	}
 }
