@@ -99,7 +99,7 @@ func extractIssues(data *JiraTaskData, mappings *typeMappings, row *api.RawData)
 	if apiIssue.Fields.Created == nil {
 		return results, nil
 	}
-	sprints, issue, worklogs, changelogs, changelogItems, users := apiIssue.ExtractEntities(data.Options.ConnectionId)
+	sprints, issue, comments, worklogs, changelogs, changelogItems, users := apiIssue.ExtractEntities(data.Options.ConnectionId)
 	for _, sprintId := range sprints {
 		sprintIssue := &models.JiraSprintIssue{
 			ConnectionId:     data.Options.ConnectionId,
@@ -113,8 +113,8 @@ func extractIssues(data *JiraTaskData, mappings *typeMappings, row *api.RawData)
 	if issue.ResolutionDate != nil {
 		issue.LeadTimeMinutes = uint(issue.ResolutionDate.Unix()-issue.Created.Unix()) / 60
 	}
-	if data.Options.TransformationRules != nil && data.Options.TransformationRules.StoryPointField != "" {
-		unknownStoryPoint := apiIssue.Fields.AllFields[data.Options.TransformationRules.StoryPointField]
+	if data.Options.ScopeConfig != nil && data.Options.ScopeConfig.StoryPointField != "" {
+		unknownStoryPoint := apiIssue.Fields.AllFields[data.Options.ScopeConfig.StoryPointField]
 		switch sp := unknownStoryPoint.(type) {
 		case string:
 			// string, try to parse
@@ -138,6 +138,9 @@ func extractIssues(data *JiraTaskData, mappings *typeMappings, row *api.RawData)
 		issue.StdStatus = value.StandardStatus
 	}
 	results = append(results, issue)
+	for _, comment := range comments {
+		results = append(results, comment)
+	}
 	for _, worklog := range worklogs {
 		results = append(results, worklog)
 	}
@@ -193,8 +196,8 @@ func getTypeMappings(data *JiraTaskData, db dal.Dal) (*typeMappings, errors.Erro
 	}
 	stdTypeMappings := make(map[string]string)
 	standardStatusMappings := make(map[string]StatusMappings)
-	if data.Options.TransformationRules != nil {
-		for userType, stdType := range data.Options.TransformationRules.TypeMappings {
+	if data.Options.ScopeConfig != nil {
+		for userType, stdType := range data.Options.ScopeConfig.TypeMappings {
 			stdTypeMappings[userType] = strings.ToUpper(stdType.StandardType)
 			standardStatusMappings[userType] = stdType.StatusMappings
 		}
