@@ -20,6 +20,7 @@ package tasks
 import (
 	"encoding/json"
 	"fmt"
+	"regexp"
 	"time"
 
 	"github.com/apache/incubator-devlake/core/errors"
@@ -38,20 +39,49 @@ type TypeMapping struct {
 	StatusMappings StatusMappings `json:"statusMappings"`
 }
 
-type TypeMappings map[string]TypeMapping
-
-type JiraTransformationRule struct {
-	ConnectionId               uint64       `mapstructure:"connectionId" json:"connectionId"`
-	Name                       string       `gorm:"type:varchar(255)" validate:"required"`
-	EpicKeyField               string       `json:"epicKeyField"`
-	StoryPointField            string       `json:"storyPointField"`
-	RemotelinkCommitShaPattern string       `json:"remotelinkCommitShaPattern"`
-	RemotelinkRepoPattern      []string     `json:"remotelinkRepoPattern"`
-	TypeMappings               TypeMappings `json:"typeMappings"`
-	ApplicationType            string       `json:"applicationType"`
+type CommitUrlPattern struct {
+	Pattern string `json:"pattern"`
+	Regex   string `json:"regex"`
 }
 
-func (r *JiraTransformationRule) ToDb() (*models.JiraTransformationRule, errors.Error) {
+type TypeMappings map[string]TypeMapping
+
+type JiraScopeConfig struct {
+	Entities                   []string           `json:"entities"`
+	ConnectionId               uint64             `mapstructure:"connectionId" json:"connectionId"`
+	Name                       string             `gorm:"type:varchar(255)" validate:"required"`
+	EpicKeyField               string             `json:"epicKeyField"`
+	StoryPointField            string             `json:"storyPointField"`
+	RemotelinkCommitShaPattern string             `json:"remotelinkCommitShaPattern"`
+	RemotelinkRepoPattern      []CommitUrlPattern `json:"remotelinkRepoPattern"`
+	TypeMappings               TypeMappings       `json:"typeMappings"`
+	ApplicationType            string             `json:"applicationType"`
+}
+
+func (r *JiraScopeConfig) VerifyRegexp() errors.Error {
+	var err error
+	if r.RemotelinkCommitShaPattern != "" {
+		_, err = regexp.Compile(r.RemotelinkCommitShaPattern)
+		if err != nil {
+			return errors.Convert(err)
+		}
+	}
+	for _, pattern := range r.RemotelinkRepoPattern {
+		if pattern.Regex == "" {
+			return errors.BadInput.New("empty regex in remotelinkRepoPattern")
+		}
+		_, err = regexp.Compile(pattern.Regex)
+		if err != nil {
+			return errors.Convert(err)
+		}
+	}
+	return nil
+}
+
+func (r *JiraScopeConfig) ToDb() (*models.JiraScopeConfig, errors.Error) {
+	if err1 := r.VerifyRegexp(); err1 != nil {
+		return nil, err1
+	}
 	blob, err := json.Marshal(r.TypeMappings)
 	if err != nil {
 		return nil, errors.Default.Wrap(err, "error marshaling TypeMappings")
@@ -63,7 +93,7 @@ func (r *JiraTransformationRule) ToDb() (*models.JiraTransformationRule, errors.
 	if err != nil {
 		return nil, errors.Default.Wrap(err, "error marshaling RemotelinkRepoPattern")
 	}
-	rule := &models.JiraTransformationRule{
+	scopeConfig := &models.JiraScopeConfig{
 		ConnectionId:               r.ConnectionId,
 		Name:                       r.Name,
 		EpicKeyField:               r.EpicKeyField,
@@ -73,13 +103,11 @@ func (r *JiraTransformationRule) ToDb() (*models.JiraTransformationRule, errors.
 		TypeMappings:               blob,
 		ApplicationType:            r.ApplicationType,
 	}
-	if err1 := rule.VerifyRegexp(); err1 != nil {
-		return nil, err1
-	}
-	return rule, nil
+	scopeConfig.Entities = r.Entities
+	return scopeConfig, nil
 }
 
-func MakeTransformationRules(rule models.JiraTransformationRule) (*JiraTransformationRule, errors.Error) {
+func MakeScopeConfig(rule models.JiraScopeConfig) (*JiraScopeConfig, errors.Error) {
 	var typeMapping TypeMappings
 	var err error
 	if len(rule.TypeMappings) > 0 {
@@ -88,14 +116,15 @@ func MakeTransformationRules(rule models.JiraTransformationRule) (*JiraTransform
 			return nil, errors.Default.Wrap(err, "unable to unmarshal the typeMapping")
 		}
 	}
-	var remotelinkRepoPattern []string
+	var remotelinkRepoPattern []CommitUrlPattern
 	if len(rule.RemotelinkRepoPattern) > 0 {
 		err = json.Unmarshal(rule.RemotelinkRepoPattern, &remotelinkRepoPattern)
 		if err != nil {
 			return nil, errors.Default.Wrap(err, "error unMarshaling RemotelinkRepoPattern")
 		}
 	}
-	result := &JiraTransformationRule{
+	result := &JiraScopeConfig{
+		Entities:                   rule.Entities,
 		ConnectionId:               rule.ConnectionId,
 		Name:                       rule.Name,
 		EpicKeyField:               rule.EpicKeyField,
@@ -109,13 +138,13 @@ func MakeTransformationRules(rule models.JiraTransformationRule) (*JiraTransform
 }
 
 type JiraOptions struct {
-	ConnectionId         uint64 `json:"connectionId"`
-	BoardId              uint64 `json:"boardId"`
-	TimeAfter            string
-	TransformationRules  *JiraTransformationRule `json:"transformationRules"`
-	ScopeId              string
-	TransformationRuleId uint64
-	PageSize             int
+	ConnectionId  uint64 `json:"connectionId"`
+	BoardId       uint64 `json:"boardId"`
+	TimeAfter     string
+	ScopeConfig   *JiraScopeConfig `json:"scopeConfig"`
+	ScopeId       string
+	ScopeConfigId uint64
+	PageSize      int
 }
 
 type JiraTaskData struct {
@@ -125,10 +154,7 @@ type JiraTaskData struct {
 	JiraServerInfo models.JiraServerInfo
 }
 
-type JiraApiParams struct {
-	ConnectionId uint64
-	BoardId      uint64
-}
+type JiraApiParams models.JiraApiParams
 
 func DecodeAndValidateTaskOptions(options map[string]interface{}) (*JiraOptions, errors.Error) {
 	var op JiraOptions
