@@ -28,5 +28,8 @@ func All() []plugin.MigrationScript {
 		new(addEndpointAndProxyToConnection),
 		new(addPagerdutyConnectionFields20230123),
 		new(addTransformationRulesToService20230303),
+		new(renameTr2ScopeConfig),
+		new(removeScopeConfig),
+		new(addRawParamTableForScope),
 	}
 }
