@@ -51,20 +51,25 @@ func (p Sonarqube) Description() string {
 	return "collect some Sonarqube data"
 }
 
+func (p Sonarqube) Name() string {
+	return "sonarqube"
+}
+
 func (p Sonarqube) Init(br context.BasicRes) errors.Error {
-	api.Init(br)
+	api.Init(br, p)
+
 	return nil
 }
 
-func (p Sonarqube) Connection() interface{} {
+func (p Sonarqube) Connection() dal.Tabler {
 	return &models.SonarqubeConnection{}
 }
 
-func (p Sonarqube) Scope() interface{} {
+func (p Sonarqube) Scope() plugin.ToolLayerScope {
 	return &models.SonarqubeProject{}
 }
 
-func (p Sonarqube) TransformationRule() interface{} {
+func (p Sonarqube) ScopeConfig() dal.Tabler {
 	return nil
 }
 
@@ -110,6 +115,7 @@ func (p Sonarqube) PrepareTaskData(taskCtx plugin.TaskContext, options map[strin
 	connectionHelper := helper.NewConnectionHelper(
 		taskCtx,
 		nil,
+		p.Name(),
 	)
 	connection := &models.SonarqubeConnection{}
 	err = connectionHelper.FirstById(connection, op.ConnectionId)
@@ -175,8 +181,9 @@ func (p Sonarqube) ApiResources() map[string]map[string]plugin.ApiResourceHandle
 			"GET": api.SearchRemoteScopes,
 		},
 		"connections/:connectionId/scopes/:scopeId": {
-			"GET":   api.GetScope,
-			"PATCH": api.UpdateScope,
+			"GET":    api.GetScope,
+			"PATCH":  api.UpdateScope,
+			"DELETE": api.DeleteScope,
 		},
 		"connections/:connectionId/scopes": {
 			"GET": api.GetScopeList,
