@@ -18,12 +18,13 @@ limitations under the License.
 package e2e
 
 import (
+	"testing"
+
 	"github.com/apache/incubator-devlake/core/models/domainlayer/ticket"
 	"github.com/apache/incubator-devlake/helpers/e2ehelper"
 	"github.com/apache/incubator-devlake/plugins/tapd/impl"
 	"github.com/apache/incubator-devlake/plugins/tapd/models"
 	"github.com/apache/incubator-devlake/plugins/tapd/tasks"
-	"testing"
 )
 
 func TestTapdBugChangelogDataFlow(t *testing.T) {
@@ -35,7 +36,7 @@ func TestTapdBugChangelogDataFlow(t *testing.T) {
 		Options: &tasks.TapdOptions{
 			ConnectionId: 1,
 			WorkspaceId:  991,
-			TransformationRules: &tasks.TransformationRules{
+			ScopeConfig: &tasks.TapdScopeConfig{
 				TypeMappings: tasks.TypeMappings{
 					"Techstory": "REQUIREMENT",
 					"技术债":       "REQUIREMENT",
