@@ -32,21 +32,37 @@ import (
 	"github.com/apache/incubator-devlake/plugins/tapd/tasks"
 )
 
-var _ plugin.PluginMeta = (*Tapd)(nil)
-var _ plugin.PluginInit = (*Tapd)(nil)
-var _ plugin.PluginTask = (*Tapd)(nil)
-var _ plugin.PluginApi = (*Tapd)(nil)
-var _ plugin.PluginModel = (*Tapd)(nil)
-var _ plugin.PluginMigration = (*Tapd)(nil)
-var _ plugin.CloseablePluginTask = (*Tapd)(nil)
+var _ interface {
+	plugin.PluginMeta
+	plugin.PluginInit
+	plugin.PluginTask
+	plugin.PluginApi
+	plugin.PluginModel
+	plugin.PluginMigration
+	plugin.CloseablePluginTask
+	plugin.PluginSource
+} = (*Tapd)(nil)
 
 type Tapd struct{}
 
 func (p Tapd) Init(basicRes context.BasicRes) errors.Error {
-	api.Init(basicRes)
+	api.Init(basicRes, p)
+
 	return nil
 }
 
+func (p Tapd) Connection() dal.Tabler {
+	return &models.TapdConnection{}
+}
+
+func (p Tapd) Scope() plugin.ToolLayerScope {
+	return &models.TapdWorkspace{}
+}
+
+func (p Tapd) ScopeConfig() dal.Tabler {
+	return &models.TapdScopeConfig{}
+}
+
 func (p Tapd) GetTablesInfo() []dal.Tabler {
 	return []dal.Tabler{
 		&models.TapdAccount{},
@@ -86,6 +102,8 @@ func (p Tapd) GetTablesInfo() []dal.Tabler {
 		&models.TapdStoryCustomFieldValue{},
 		&models.TapdTaskCustomFieldValue{},
 		&models.TapdBugCustomFieldValue{},
+		&models.TapdScopeConfig{},
+		&models.TapdWorkitemType{},
 	}
 }
 
@@ -93,6 +111,10 @@ func (p Tapd) Description() string {
 	return "To collect and enrich data from Tapd"
 }
 
+func (p Tapd) Name() string {
+	return "tapd"
+}
+
 func (p Tapd) SubTaskMetas() []plugin.SubTaskMeta {
 	return []plugin.SubTaskMeta{
 		tasks.ConvertWorkspaceMeta,
@@ -172,6 +194,7 @@ func (p Tapd) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]int
 	connectionHelper := helper.NewConnectionHelper(
 		taskCtx,
 		nil,
+		p.Name(),
 	)
 	err = connectionHelper.FirstById(connection, op.ConnectionId)
 	if err != nil {
@@ -206,20 +229,20 @@ func (p Tapd) PrepareTaskData(taskCtx plugin.TaskContext, options map[string]int
 			return nil, errors.Default.Wrap(err, fmt.Sprintf("fail to find workspace: %d", op.WorkspaceId))
 		}
 		op.WorkspaceId = scope.Id
-		if op.TransformationRuleId == 0 {
-			op.TransformationRuleId = scope.TransformationRuleId
+		if op.ScopeConfigId == 0 {
+			op.ScopeConfigId = scope.ScopeConfigId
 		}
 	}
 
-	if op.TransformationRules == nil && op.TransformationRuleId != 0 {
-		var transformationRule models.TapdTransformationRule
-		err = taskCtx.GetDal().First(&transformationRule, dal.Where("id = ?", op.TransformationRuleId))
+	if op.ScopeConfig == nil && op.ScopeConfigId != 0 {
+		var scopeConfig models.TapdScopeConfig
+		err = taskCtx.GetDal().First(&scopeConfig, dal.Where("id = ?", op.ScopeConfigId))
 		if err != nil && taskCtx.GetDal().IsErrorNotFound(err) {
-			return nil, errors.BadInput.Wrap(err, "fail to get transformationRule")
+			return nil, errors.BadInput.Wrap(err, "fail to get scopeConfig")
 		}
-		op.TransformationRules, err = tasks.MakeTransformationRules(transformationRule)
+		op.ScopeConfig, err = tasks.MakeScopeConfigs(scopeConfig)
 		if err != nil {
-			return nil, errors.BadInput.Wrap(err, "fail to make transformationRule")
+			return nil, errors.BadInput.Wrap(err, "fail to make scopeConfig")
 		}
 	}
 
@@ -278,8 +301,9 @@ func (p Tapd) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"GET": api.Proxy,
 		},
 		"connections/:connectionId/scopes/:scopeId": {
-			"GET":   api.GetScope,
-			"PATCH": api.UpdateScope,
+			"GET":    api.GetScope,
+			"PATCH":  api.UpdateScope,
+			"DELETE": api.DeleteScope,
 		},
 		"connections/:connectionId/remote-scopes-prepare-token": {
 			"GET": api.PrepareFirstPageToken,
@@ -291,13 +315,14 @@ func (p Tapd) ApiResources() map[string]map[string]plugin.ApiResourceHandler {
 			"GET": api.GetScopeList,
 			"PUT": api.PutScope,
 		},
-		"connections/:connectionId/transformation_rules": {
-			"POST": api.CreateTransformationRule,
-			"GET":  api.GetTransformationRuleList,
+		"connections/:connectionId/scope-configs": {
+			"POST": api.CreateScopeConfig,
+			"GET":  api.GetScopeConfigList,
 		},
-		"connections/:connectionId/transformation_rules/:id": {
-			"PATCH": api.UpdateTransformationRule,
-			"GET":   api.GetTransformationRule,
+		"connections/:connectionId/scope-configs/:id": {
+			"PATCH":  api.UpdateScopeConfig,
+			"GET":    api.GetScopeConfig,
+			"DELETE": api.DeleteScopeConfig,
 		},
 	}
 }
