@@ -30,5 +30,7 @@ func All() []plugin.MigrationScript {
 		new(deleteIssue),
 		new(modifyCustomFieldName),
 		new(addCustomFieldValue),
+		new(renameTr2ScopeConfig),
+		new(addRawParamTableForScope),
 	}
 }
