@@ -33,20 +33,11 @@ import (
 
 const RAW_TASK_TABLE = "zentao_api_tasks"
 
-type ExecuteInput struct {
-	Id int64
-}
-
 var _ plugin.SubTaskEntryPoint = CollectTask
 
 func CollectTask(taskCtx plugin.SubTaskContext) errors.Error {
 	data := taskCtx.GetData().(*ZentaoTaskData)
 
-	// this collect only work for project
-	if data.Options.ProjectId == 0 {
-		return nil
-	}
-
 	cursor, err := taskCtx.GetDal().Cursor(
 		dal.Select(`id`),
 		dal.From(&models.ZentaoExecution{}),
@@ -57,20 +48,16 @@ func CollectTask(taskCtx plugin.SubTaskContext) errors.Error {
 	}
 	defer cursor.Close()
 
-	iterator, err := api.NewDalCursorIterator(taskCtx.GetDal(), cursor, reflect.TypeOf(ExecuteInput{}))
+	iterator, err := api.NewDalCursorIterator(taskCtx.GetDal(), cursor, reflect.TypeOf(input{}))
 	if err != nil {
 		return err
 	}
 
 	collector, err := api.NewApiCollector(api.ApiCollectorArgs{
 		RawDataSubTaskArgs: api.RawDataSubTaskArgs{
-			Ctx: taskCtx,
-			Params: ZentaoApiParams{
-				ConnectionId: data.Options.ConnectionId,
-				ProductId:    data.Options.ProductId,
-				ProjectId:    data.Options.ProjectId,
-			},
-			Table: RAW_TASK_TABLE,
+			Ctx:     taskCtx,
+			Options: data.Options,
+			Table:   RAW_TASK_TABLE,
 		},
 		Input:       iterator,
 		ApiClient:   data.ApiClient,
@@ -80,6 +67,7 @@ func CollectTask(taskCtx plugin.SubTaskContext) errors.Error {
 			query := url.Values{}
 			query.Set("page", fmt.Sprintf("%v", reqData.Pager.Page))
 			query.Set("limit", fmt.Sprintf("%v", reqData.Pager.Size))
+			query.Set("status", "all")
 			return query, nil
 		},
 		GetTotalPages: GetTotalPagesFromResponse,
@@ -88,6 +76,9 @@ func CollectTask(taskCtx plugin.SubTaskContext) errors.Error {
 				Task []json.RawMessage `json:"tasks"`
 			}
 			err := api.UnmarshalResponse(res, &data)
+			if errors.Is(err, api.ErrEmptyResponse) {
+				return nil, nil
+			}
 			if err != nil {
 				return nil, errors.Default.Wrap(err, "error reading endpoint response by Zentao bug collector")
 			}
@@ -101,7 +92,7 @@ func CollectTask(taskCtx plugin.SubTaskContext) errors.Error {
 }
 
 var CollectTaskMeta = plugin.SubTaskMeta{
-	Name:             "CollectTask",
+	Name:             "collectTask",
 	EntryPoint:       CollectTask,
 	EnabledByDefault: true,
 	Description:      "Collect Task data from Zentao api",
