@@ -20,6 +20,8 @@ from pydantic import BaseModel, Field
 import jsonref
 
 from pydevlake.model import ToolScope
+from pydevlake.migration import MigrationScript
+from pydevlake.api import Response
 
 
 class Message(BaseModel):
@@ -43,11 +45,15 @@ class DynamicModelInfo(Message):
 
     @staticmethod
     def from_model(model_class):
-        schema = model_class.schema()
+        schema = model_class.schema(by_alias=True)
         if 'definitions' in schema:
             # Replace $ref with actual schema
             schema = jsonref.replace_refs(schema, proxies=False)
             del schema['definitions']
+        # Pydantic forgets to put type in enums
+        for prop in schema['properties'].values():
+            if 'type' not in prop and 'enum' in prop:
+                prop['type'] = 'string'
         return DynamicModelInfo(
             json_schema=schema,
             table_name=model_class.__tablename__
@@ -58,12 +64,13 @@ class PluginInfo(Message):
     name: str
     description: str
     connection_model_info: DynamicModelInfo
-    transformation_rule_model_info: Optional[DynamicModelInfo]
     scope_model_info: DynamicModelInfo
+    scope_config_model_info: Optional[DynamicModelInfo]
+    tool_model_infos: list[DynamicModelInfo]
+    migration_scripts: list[MigrationScript]
     plugin_path: str
     subtask_metas: list[SubtaskMeta]
     extension: str = "datasource"
-    type: str = "python-poetry"
 
 
 class RemoteProgress(Message):
@@ -106,3 +113,20 @@ class RemoteScope(RemoteScopeTreeNode):
 
 class RemoteScopes(Message):
     __root__: list[RemoteScopeTreeNode]
+
+
+class TestConnectionResult(Message):
+    success: bool
+    message: str
+    status: int
+
+    @staticmethod
+    def from_api_response(response: Response, message: str = None):
+        success = response.status == 200
+        if not message:
+            message = "Connection successful" if success else "Connection failed"
+        return TestConnectionResult(
+            success=success,
+            message=message,
+            status=response.status
+        )
