@@ -26,8 +26,8 @@ import (
 
 	"github.com/gin-contrib/cors"
 	"github.com/gin-gonic/gin"
+	swaggerFiles "github.com/swaggo/files"
 	ginSwagger "github.com/swaggo/gin-swagger"
-	"github.com/swaggo/gin-swagger/swaggerFiles"
 	"github.com/swaggo/swag"
 
 	"github.com/apache/incubator-devlake/core/config"
@@ -35,12 +35,10 @@ import (
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/impls/logruslog"
 	_ "github.com/apache/incubator-devlake/server/api/docs"
-	"github.com/apache/incubator-devlake/server/api/login"
 	"github.com/apache/incubator-devlake/server/api/ping"
 	"github.com/apache/incubator-devlake/server/api/shared"
 	"github.com/apache/incubator-devlake/server/api/version"
 	"github.com/apache/incubator-devlake/server/services"
-	"github.com/apache/incubator-devlake/server/services/auth"
 )
 
 const DB_MIGRATION_REQUIRED = `
@@ -57,28 +55,25 @@ Alternatively, you may downgrade back to the previous DevLake version.
 // @host localhost:8080
 // @BasePath /
 func CreateApiService() {
-	// Initialize services
-	services.Init()
 	// Get configuration
 	v := config.GetConfig()
+	// Initialize services
+	services.Init()
 	// Set gin mode
 	gin.SetMode(v.GetString("MODE"))
 	// Create a gin router
 	router := gin.Default()
 
-	// Check if AWS Cognito is enabled
-	awsCognitoEnabled := v.GetBool("AWS_ENABLE_COGNITO")
-
 	// For both protected and unprotected routes
 	router.GET("/ping", ping.Get)
 	router.GET("/version", version.Get)
-
-	if awsCognitoEnabled {
-		// Add login endpoint
-		router.POST("/login", login.Login)
-		// Use AuthenticationMiddleware for protected routes
-		router.Use(auth.AuthenticationMiddleware)
-	}
+	router.GET("/userinfo", func(ctx *gin.Context) {
+		shared.ApiOutputSuccess(ctx, gin.H{
+			"user":      ctx.Request.Header.Get("X-Forwarded-User"),
+			"email":     ctx.Request.Header.Get("X-Forwarded-Email"),
+			"logoutURI": config.GetConfig().GetString("LOGOUT_URI"),
+		}, http.StatusOK)
+	})
 
 	// Endpoint to proceed database migration
 	router.GET("/proceed-db-migration", func(ctx *gin.Context) {
