@@ -19,6 +19,8 @@ package api
 
 import (
 	"fmt"
+	"github.com/apache/incubator-devlake/core/errors"
+	"github.com/apache/incubator-devlake/impls/logruslog"
 	"net/http"
 	"strings"
 
@@ -40,23 +42,21 @@ func RegisterRouter(r *gin.Engine) {
 	r.GET("/pipelines", pipelines.Index)
 	r.POST("/pipelines", pipelines.Post)
 	r.GET("/pipelines/:pipelineId", pipelines.Get)
-	r.PATCH("/blueprints/:blueprintId", blueprints.Patch)
-	r.POST("/blueprints/:blueprintId/trigger", blueprints.Trigger)
-	// r.DELETE("/blueprints/:blueprintId", blueprints.Delete)
-
-	r.GET("/blueprints", blueprints.Index)
-	r.POST("/blueprints", blueprints.Post)
-	r.GET("/blueprints/:blueprintId", blueprints.Get)
-	r.GET("/blueprints/:blueprintId/pipelines", blueprints.GetBlueprintPipelines)
 	r.DELETE("/pipelines/:pipelineId", pipelines.Delete)
 	r.GET("/pipelines/:pipelineId/tasks", task.GetTaskByPipeline)
 	r.POST("/pipelines/:pipelineId/rerun", pipelines.PostRerun)
-	r.POST("/tasks/:taskId/rerun", task.PostRerun)
-
 	r.GET("/pipelines/:pipelineId/logging.tar.gz", pipelines.DownloadLogs)
 
-	//r.GET("/ping", ping.Get)
-	//r.GET("/version", version.Get)
+	r.GET("/blueprints", blueprints.Index)
+	r.POST("/blueprints", blueprints.Post)
+	r.PATCH("/blueprints/:blueprintId", blueprints.Patch)
+	r.DELETE("/blueprints/:blueprintId", blueprints.Delete)
+	r.GET("/blueprints/:blueprintId", blueprints.Get)
+	r.POST("/blueprints/:blueprintId/trigger", blueprints.Trigger)
+	r.GET("/blueprints/:blueprintId/pipelines", blueprints.GetBlueprintPipelines)
+
+	r.POST("/tasks/:taskId/rerun", task.PostRerun)
+
 	r.POST("/push/:tableName", push.Post)
 	r.GET("/domainlayer/repos", domainlayer.ReposIndex)
 
@@ -67,7 +67,7 @@ func RegisterRouter(r *gin.Engine) {
 	// project api
 	r.GET("/projects/*projectName", project.GetProject)
 	r.PATCH("/projects/*projectName", project.PatchProject)
-	//r.DELETE("/projects/:projectName", project.DeleteProject)
+	r.DELETE("/projects/*projectName", project.DeleteProject)
 	r.POST("/projects", project.PostProject)
 	r.GET("/projects", project.GetProjects)
 
@@ -88,37 +88,43 @@ func registerPluginEndpoints(r *gin.Engine, pluginName string, apiResources map[
 			r.Handle(
 				method,
 				fmt.Sprintf("/plugins/%s/%s", pluginName, resourcePath),
-				handlePluginCall(h),
+				handlePluginCall(pluginName, h),
 			)
 		}
 	}
 }
 
-func handlePluginCall(handler plugin.ApiResourceHandler) func(c *gin.Context) {
+func handlePluginCall(pluginName string, handler plugin.ApiResourceHandler) func(c *gin.Context) {
 	return func(c *gin.Context) {
-		var err error
+		var err errors.Error
 		input := &plugin.ApiResourceInput{}
+		input.Params = make(map[string]string)
 		if len(c.Params) > 0 {
-			input.Params = make(map[string]string)
 			for _, param := range c.Params {
 				input.Params[param.Key] = param.Value
 			}
 		}
+		input.Params["plugin"] = pluginName
 		input.Query = c.Request.URL.Query()
 		if c.Request.Body != nil {
 			if strings.HasPrefix(c.Request.Header.Get("Content-Type"), "multipart/form-data;") {
 				input.Request = c.Request
 			} else {
-				err = c.ShouldBindJSON(&input.Body)
-				if err != nil && err.Error() != "EOF" {
-					shared.ApiOutputError(c, err)
+				err2 := c.ShouldBindJSON(&input.Body)
+				if err2 != nil && err2.Error() != "EOF" {
+					shared.ApiOutputError(c, err2)
 					return
 				}
 			}
 		}
 		output, err := handler(input)
 		if err != nil {
-			shared.ApiOutputError(c, err)
+			if output != nil && output.Body != nil {
+				logruslog.Global.Error(err, "")
+				shared.ApiOutputSuccess(c, output.Body, err.GetType().GetHttpCode())
+			} else {
+				shared.ApiOutputError(c, err)
+			}
 		} else if output != nil {
 			status := output.Status
 			if status < http.StatusContinue {
