@@ -26,15 +26,9 @@ import (
 
 func main() {
 	v := config.GetConfig()
-	encKey := v.GetString(plugin.EncodeKeyEnvStr)
-	if encKey == "" {
-		// Randomly generate a bunch of encryption keys and set them to config
-		encKey = plugin.RandomEncKey()
-		v.Set(plugin.EncodeKeyEnvStr, encKey)
-		err := config.WriteConfig(v)
-		if err != nil {
-			panic(err)
-		}
+	encryptionSecret := v.GetString(plugin.EncodeKeyEnvStr)
+	if encryptionSecret == "" {
+		panic("ENCRYPTION_SECRET must be set in environment variable or .env file")
 	}
 	api.CreateApiService()
 }
