@@ -22,6 +22,8 @@ import (
 	"fmt"
 	"strings"
 
+	"github.com/apache/incubator-devlake/helpers/pluginhelper/services"
+
 	"github.com/apache/incubator-devlake/core/dal"
 	"github.com/apache/incubator-devlake/core/errors"
 	"github.com/apache/incubator-devlake/core/models"
@@ -31,6 +33,11 @@ import (
 	"github.com/robfig/cron/v3"
 )
 
+var (
+	blueprintLog = logruslog.Global.Nested("blueprint")
+	ErrEmptyPlan = errors.Default.New("empty plan")
+)
+
 // BlueprintQuery is a query for GetBlueprints
 type BlueprintQuery struct {
 	Pagination
@@ -39,17 +46,17 @@ type BlueprintQuery struct {
 	Label    string `form:"label"`
 }
 
-var (
-	blueprintLog = logruslog.Global.Nested("blueprint")
-)
-
 type BlueprintJob struct {
 	Blueprint *models.Blueprint
 }
 
 func (bj BlueprintJob) Run() {
 	blueprint := bj.Blueprint
-	pipeline, err := createPipelineByBlueprint(blueprint)
+	pipeline, err := createPipelineByBlueprint(blueprint, false)
+	if err == ErrEmptyPlan {
+		blueprintLog.Info("Empty plan, blueprint id:[%d] blueprint name:[%s]", blueprint.ID, blueprint.Name)
+		return
+	}
 	if err != nil {
 		blueprintLog.Error(err, fmt.Sprintf("run cron job failed on blueprint:[%d][%s]", blueprint.ID, blueprint.Name))
 	} else {
@@ -63,7 +70,7 @@ func CreateBlueprint(blueprint *models.Blueprint) errors.Error {
 	if err != nil {
 		return err
 	}
-	err = SaveDbBlueprint(blueprint)
+	err = bpManager.SaveDbBlueprint(blueprint)
 	if err != nil {
 		return err
 	}
@@ -76,7 +83,13 @@ func CreateBlueprint(blueprint *models.Blueprint) errors.Error {
 
 // GetBlueprints returns a paginated list of Blueprints based on `query`
 func GetBlueprints(query *BlueprintQuery) ([]*models.Blueprint, int64, errors.Error) {
-	blueprints, count, err := GetDbBlueprints(query)
+	blueprints, count, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
+		Enable:      query.Enable,
+		IsManual:    query.IsManual,
+		Label:       query.Label,
+		SkipRecords: query.GetSkip(),
+		PageSize:    query.GetPageSize(),
+	})
 	if err != nil {
 		return nil, 0, errors.Convert(err)
 	}
@@ -85,7 +98,7 @@ func GetBlueprints(query *BlueprintQuery) ([]*models.Blueprint, int64, errors.Er
 
 // GetBlueprint returns the detail of a given Blueprint ID
 func GetBlueprint(blueprintId uint64) (*models.Blueprint, errors.Error) {
-	blueprint, err := GetDbBlueprint(blueprintId)
+	blueprint, err := bpManager.GetDbBlueprint(blueprintId)
 	if err != nil {
 		if db.IsErrorNotFound(err) {
 			return nil, errors.NotFound.New("blueprint not found")
@@ -100,7 +113,7 @@ func GetBlueprintByProjectName(projectName string) (*models.Blueprint, errors.Er
 	if projectName == "" {
 		return nil, errors.Internal.New("can not use the empty projectName to search the unique blueprint")
 	}
-	blueprint, err := GetDbBlueprintByProjectName(projectName)
+	blueprint, err := bpManager.GetDbBlueprintByProjectName(projectName)
 	if err != nil {
 		// Allow specific projectName to fail to find the corresponding blueprint
 		if db.IsErrorNotFound(err) {
@@ -154,12 +167,8 @@ func validateBlueprintAndMakePlan(blueprint *models.Blueprint) errors.Error {
 		if err != nil {
 			return errors.Default.Wrap(err, "invalid plan")
 		}
-		// tasks should not be empty
-		if len(plan) == 0 || len(plan[0]) == 0 {
-			return errors.Default.New("empty plan")
-		}
 	} else if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
-		plan, err := MakePlanForBlueprint(blueprint)
+		plan, err := MakePlanForBlueprint(blueprint, false)
 		if err != nil {
 			return errors.Default.Wrap(err, "make plan for blueprint failed")
 		}
@@ -177,7 +186,7 @@ func saveBlueprint(blueprint *models.Blueprint) (*models.Blueprint, errors.Error
 	if err != nil {
 		return nil, errors.BadInput.WrapRaw(err)
 	}
-	err = SaveDbBlueprint(blueprint)
+	err = bpManager.SaveDbBlueprint(blueprint)
 	if err != nil {
 		return nil, err
 	}
@@ -204,7 +213,7 @@ func PatchBlueprint(id uint64, body map[string]interface{}) (*models.Blueprint,
 	if err != nil {
 		return nil, err
 	}
-	// make sure mode is not being update
+	// make sure mode is not being updated
 	if originMode != blueprint.Mode {
 		return nil, errors.Default.New("mode is not updatable")
 	}
@@ -217,11 +226,27 @@ func PatchBlueprint(id uint64, body map[string]interface{}) (*models.Blueprint,
 	return blueprint, nil
 }
 
+// DeleteBlueprint FIXME ...
+func DeleteBlueprint(id uint64) errors.Error {
+	bp, err := bpManager.GetDbBlueprint(id)
+	if err != nil {
+		return err
+	}
+	err = bpManager.DeleteBlueprint(bp.ID)
+	if err != nil {
+		return errors.Default.Wrap(err, "Failed to delete the blueprint")
+	}
+	return nil
+}
+
 // ReloadBlueprints FIXME ...
 func ReloadBlueprints(c *cron.Cron) errors.Error {
 	enable := true
 	isManual := false
-	blueprints, _, err := GetDbBlueprints(&BlueprintQuery{Enable: &enable, IsManual: &isManual})
+	blueprints, _, err := bpManager.GetDbBlueprints(&services.GetBlueprintQuery{
+		Enable:   &enable,
+		IsManual: &isManual,
+	})
 	if err != nil {
 		return err
 	}
@@ -230,16 +255,10 @@ func ReloadBlueprints(c *cron.Cron) errors.Error {
 	}
 	c.Stop()
 	for _, blueprint := range blueprints {
-		if err != nil {
-			blueprintLog.Error(err, failToCreateCronJob)
-			return err
-		}
-
 		blueprintLog.Info("Add blueprint id:[%d] cronConfg[%s] to cron job", blueprint.ID, blueprint.CronConfig)
 		blueprintJob := &BlueprintJob{
 			Blueprint: blueprint,
 		}
-
 		if _, err := c.AddJob(blueprint.CronConfig, blueprintJob); err != nil {
 			blueprintLog.Error(err, failToCreateCronJob)
 			return errors.Default.Wrap(err, "created cron job failed")
@@ -252,11 +271,11 @@ func ReloadBlueprints(c *cron.Cron) errors.Error {
 	return nil
 }
 
-func createPipelineByBlueprint(blueprint *models.Blueprint) (*models.Pipeline, errors.Error) {
+func createPipelineByBlueprint(blueprint *models.Blueprint, skipCollectors bool) (*models.Pipeline, errors.Error) {
 	var plan plugin.PipelinePlan
 	var err errors.Error
 	if blueprint.Mode == models.BLUEPRINT_MODE_NORMAL {
-		plan, err = MakePlanForBlueprint(blueprint)
+		plan, err = MakePlanForBlueprint(blueprint, skipCollectors)
 	} else {
 		plan, err = blueprint.UnmarshalPlan()
 	}
@@ -270,6 +289,23 @@ func createPipelineByBlueprint(blueprint *models.Blueprint) (*models.Pipeline, e
 	newPipeline.BlueprintId = blueprint.ID
 	newPipeline.Labels = blueprint.Labels
 	newPipeline.SkipOnFail = blueprint.SkipOnFail
+
+	// if the plan is empty, we should not create the pipeline
+	var shouldCreatePipeline bool
+	for _, stage := range plan {
+		for _, task := range stage {
+			switch task.Plugin {
+			case "org", "refdiff", "dora":
+			default:
+				if !plan.IsEmpty() {
+					shouldCreatePipeline = true
+				}
+			}
+		}
+	}
+	if !shouldCreatePipeline {
+		return nil, ErrEmptyPlan
+	}
 	pipeline, err := CreatePipeline(&newPipeline)
 	// Return all created tasks to the User
 	if err != nil {
@@ -280,7 +316,7 @@ func createPipelineByBlueprint(blueprint *models.Blueprint) (*models.Pipeline, e
 }
 
 // MakePlanForBlueprint generates pipeline plan by version
-func MakePlanForBlueprint(blueprint *models.Blueprint) (plugin.PipelinePlan, errors.Error) {
+func MakePlanForBlueprint(blueprint *models.Blueprint, skipCollectors bool) (plugin.PipelinePlan, errors.Error) {
 	bpSettings := new(models.BlueprintSettings)
 	err := errors.Convert(json.Unmarshal(blueprint.Settings, bpSettings))
 	if err != nil {
@@ -293,8 +329,7 @@ func MakePlanForBlueprint(blueprint *models.Blueprint) (plugin.PipelinePlan, err
 	var plan plugin.PipelinePlan
 	switch bpSettings.Version {
 	case "1.0.0":
-		// Notice: v1 not complete SkipOnFail & TimeAfter
-		plan, err = GeneratePlanJsonV100(bpSettings)
+		return nil, errors.BadInput.New("Blueprint v1.0.0 had been deprecated, please se v2.0.0 instead")
 	case "2.0.0":
 		// load project metric plugins and convert it to a map
 		metrics := make(map[string]json.RawMessage)
@@ -308,7 +343,7 @@ func MakePlanForBlueprint(blueprint *models.Blueprint) (plugin.PipelinePlan, err
 				metrics[projectMetric.PluginName] = json.RawMessage(projectMetric.PluginOption)
 			}
 		}
-		plan, err = GeneratePlanJsonV200(blueprint.ProjectName, bpSyncPolicy, bpSettings, metrics)
+		plan, err = GeneratePlanJsonV200(blueprint.ProjectName, bpSyncPolicy, bpSettings, metrics, skipCollectors)
 	default:
 		return nil, errors.Default.New(fmt.Sprintf("unknown version of blueprint settings: %s", bpSettings.Version))
 	}
@@ -369,13 +404,12 @@ func SequencializePipelinePlans(plans ...plugin.PipelinePlan) plugin.PipelinePla
 }
 
 // TriggerBlueprint triggers blueprint immediately
-func TriggerBlueprint(id uint64) (*models.Pipeline, errors.Error) {
+func TriggerBlueprint(id uint64, skipCollectors bool) (*models.Pipeline, errors.Error) {
 	// load record from db
 	blueprint, err := GetBlueprint(id)
 	if err != nil {
+		logger.Error(err, "GetBlueprint, id: %d", id)
 		return nil, err
 	}
-	pipeline, err := createPipelineByBlueprint(blueprint)
-	// done
-	return pipeline, err
+	return createPipelineByBlueprint(blueprint, skipCollectors)
 }
