@@ -113,17 +113,11 @@ func GetProject(name string) (*models.ApiOutputProject, errors.Error) {
 	if name == "" {
 		return nil, errors.BadInput.New("project name is missing")
 	}
-
 	// load project
-	project := &models.Project{}
-	err := db.First(project, dal.Where("name = ?", name))
+	project, err := getProjectByName(db, name)
 	if err != nil {
-		if db.IsErrorNotFound(err) {
-			return nil, errors.NotFound.Wrap(err, fmt.Sprintf("could not find project [%s] in DB", name))
-		}
-		return nil, errors.Default.Wrap(err, "error getting project from DB")
+		return nil, err
 	}
-
 	// convert to api output
 	return makeProjectOutput(&project.BaseProject)
 }
@@ -149,8 +143,7 @@ func PatchProject(name string, body map[string]interface{}) (*models.ApiOutputPr
 		}
 	}()
 
-	project := &models.Project{}
-	err = tx.First(project, dal.Where("name = ?", name), dal.Lock(true, false))
+	project, err := getProjectByName(tx, name, dal.Lock(true, false))
 	if err != nil {
 		return nil, err
 	}
@@ -254,6 +247,80 @@ func PatchProject(name string, body map[string]interface{}) (*models.ApiOutputPr
 	return makeProjectOutput(&projectInput.BaseProject)
 }
 
+// DeleteProject FIXME ...
+func DeleteProject(name string) errors.Error {
+	// verify input
+	if name == "" {
+		return errors.BadInput.New("project name is missing")
+	}
+	// verify exists
+	_, err := getProjectByName(db, name)
+	if err != nil {
+		return err
+	}
+	err = deleteProjectBlueprint(name)
+	if err != nil {
+		return err
+	}
+	tx := db.Begin()
+	defer func() {
+		if r := recover(); r != nil || err != nil {
+			err = tx.Rollback()
+			if err != nil {
+				logger.Error(err, "DeleteProject: failed to rollback")
+			}
+		}
+	}()
+	err = tx.Delete(&models.Project{}, dal.Where("name = ?", name))
+	if err != nil {
+		return errors.Default.Wrap(err, "error deleting project")
+	}
+	err = tx.Delete(&crossdomain.ProjectMapping{}, dal.Where("project_name = ?", name))
+	if err != nil {
+		return errors.Default.Wrap(err, "error deleting project")
+	}
+	err = tx.Delete(&models.ProjectMetricSetting{}, dal.Where("project_name = ?", name))
+	if err != nil {
+		return errors.Default.Wrap(err, "error deleting project metric setting")
+	}
+	err = tx.Delete(&crossdomain.ProjectPrMetric{}, dal.Where("project_name = ?", name))
+	if err != nil {
+		return errors.Default.Wrap(err, "error deleting project PR metric")
+	}
+	err = tx.Delete(&crossdomain.ProjectIssueMetric{}, dal.Where("project_name = ?", name))
+	if err != nil {
+		return errors.Default.Wrap(err, "error deleting project Issue metric")
+	}
+	return tx.Commit()
+}
+
+func deleteProjectBlueprint(projectName string) errors.Error {
+	bp, err := bpManager.GetDbBlueprintByProjectName(projectName)
+	if err != nil {
+		if !db.IsErrorNotFound(err) {
+			return errors.Default.Wrap(err, fmt.Sprintf("error finding blueprint associated with project %s", projectName))
+		}
+	} else {
+		err = bpManager.DeleteBlueprint(bp.ID)
+		if err != nil {
+			return errors.Default.Wrap(err, fmt.Sprintf("error deleting blueprint associated with project %s", projectName))
+		}
+	}
+	return nil
+}
+
+func getProjectByName(tx dal.Dal, name string, additionalClauses ...dal.Clause) (*models.Project, errors.Error) {
+	project := &models.Project{}
+	err := tx.First(project, append([]dal.Clause{dal.Where("name = ?", name)}, additionalClauses...)...)
+	if err != nil {
+		if tx.IsErrorNotFound(err) {
+			return nil, errors.NotFound.Wrap(err, fmt.Sprintf("could not find project [%s] in DB", name))
+		}
+		return nil, errors.Default.Wrap(err, "error getting project from DB")
+	}
+	return project, nil
+}
+
 func refreshProjectMetrics(tx dal.Transaction, projectInput *models.ApiInputProject) errors.Error {
 	err := tx.Delete(&models.ProjectMetricSetting{}, dal.Where("project_name = ?", projectInput.Name))
 	if err != nil {
