@@ -28,5 +28,8 @@ type RemotePlugin interface {
 	plugin.PluginTask
 	plugin.PluginMeta
 	plugin.PluginOpenApiSpec
-	RunMigrations(forceMigrate bool) errors.Error
+	plugin.PluginModel
+	plugin.PluginMigration
+	plugin.PluginSource
+	RunAutoMigrations() errors.Error
 }
