@@ -22,31 +22,32 @@ import (
 	"github.com/apache/incubator-devlake/core/plugin"
 	"github.com/apache/incubator-devlake/helpers/pluginhelper/api"
 	"github.com/apache/incubator-devlake/server/services/remote/bridge"
+	remoteModel "github.com/apache/incubator-devlake/server/services/remote/models"
 )
 
 type pluginAPI struct {
-	invoker    bridge.Invoker
-	connType   *models.DynamicTabler
-	txRuleType *models.DynamicTabler
-	scopeType  *models.DynamicTabler
-	helper     *api.ConnectionApiHelper
+	invoker         bridge.Invoker
+	connType        models.DynamicTabler
+	scopeType       models.DynamicTabler
+	scopeConfigType models.DynamicTabler
+	connhelper      *api.ConnectionApiHelper
+	scopeHelper     *api.GenericScopeApiHelper[remoteModel.RemoteConnection, remoteModel.DynamicScopeModel, remoteModel.RemoteScopeConfig]
 }
 
 func GetDefaultAPI(
 	invoker bridge.Invoker,
-	connType *models.DynamicTabler,
-	txRuleType *models.DynamicTabler,
-	scopeType *models.DynamicTabler,
-	helper *api.ConnectionApiHelper,
+	connType models.DynamicTabler,
+	scopeConfigType models.DynamicTabler,
+	scopeType models.DynamicTabler,
+	connHelper *api.ConnectionApiHelper,
 ) map[string]map[string]plugin.ApiResourceHandler {
 	papi := &pluginAPI{
-		invoker:    invoker,
-		connType:   connType,
-		txRuleType: txRuleType,
-		scopeType:  scopeType,
-		helper:     helper,
+		invoker:         invoker,
+		connType:        connType,
+		scopeConfigType: scopeConfigType,
+		scopeType:       scopeType,
+		connhelper:      connHelper,
 	}
-
 	resources := map[string]map[string]plugin.ApiResourceHandler{
 		"test": {
 			"POST": papi.TestConnection,
@@ -64,9 +65,20 @@ func GetDefaultAPI(
 			"PUT": papi.PutScope,
 			"GET": papi.ListScopes,
 		},
-		"connections/:connectionId/scopes/:scopeId": {
-			"GET":   papi.GetScope,
-			"PATCH": papi.PatchScope,
+		// Use `*` to match scopeId with `/` in it
+		"connections/:connectionId/scopes/*scopeId": {
+			"GET":    papi.GetScope,
+			"PATCH":  papi.UpdateScope,
+			"DELETE": papi.DeleteScope,
+		},
+		"connections/:connectionId/scope-configs": {
+			"POST": papi.PostScopeConfigs,
+			"GET":  papi.ListScopeConfigs,
+		},
+		"connections/:connectionId/scope-configs/:id": {
+			"GET":    papi.GetScopeConfig,
+			"PATCH":  papi.PatchScopeConfig,
+			"DELETE": papi.DeleteScopeConfig,
 		},
 		"connections/:connectionId/remote-scopes": {
 			"GET": papi.GetRemoteScopes,
@@ -75,17 +87,24 @@ func GetDefaultAPI(
 			"GET": papi.SearchRemoteScopes,
 		},
 	}
-
-	if txRuleType != nil {
-		resources["connections/:connectionId/transformation_rules"] = map[string]plugin.ApiResourceHandler{
-			"POST": papi.PostTransformationRules,
-			"GET":  papi.ListTransformationRules,
-		}
-		resources["connections/:connectionId/transformation_rules/:id"] = map[string]plugin.ApiResourceHandler{
-			"GET":   papi.GetTransformationRule,
-			"PATCH": papi.PatchTransformationRule,
-		}
-	}
-
+	papi.createScopeHelper()
 	return resources
 }
+
+func (pa *pluginAPI) createScopeHelper() {
+	params := &api.ReflectionParameters{
+		ScopeIdFieldName:  "Id",
+		ScopeIdColumnName: "id",
+		RawScopeParamName: "ScopeId",
+	}
+	pa.scopeHelper = api.NewGenericScopeHelper[remoteModel.RemoteConnection, remoteModel.DynamicScopeModel, remoteModel.RemoteScopeConfig](
+		basicRes,
+		vld,
+		pa.connhelper,
+		NewScopeDatabaseHelperImpl(pa, basicRes, params),
+		params,
+		&api.ScopeHelperOptions{
+			IsRemote: true,
+		},
+	)
+}
