@@ -18,6 +18,8 @@ limitations under the License.
 package helper
 
 import (
+	"github.com/apache/incubator-devlake/core/config"
+	"github.com/apache/incubator-devlake/core/models"
 	"time"
 
 	"github.com/apache/incubator-devlake/core/plugin"
@@ -35,6 +37,12 @@ type (
 		EnableDora         bool
 		MetricPlugins      []ProjectPlugin
 	}
+
+	ScopeResponse struct {
+		Scope       any
+		ScopeConfig any
+		Blueprints  []*models.Blueprint
+	}
 )
 
 type Connection struct {
@@ -84,3 +92,12 @@ type SearchRemoteScopesQuery struct {
 	PageSize     int
 	Params       map[string]string
 }
+
+func SetTestConfig[T any](t T) {
+	config.GetConfig().Set("TEST_CONFIG", t)
+}
+
+func GetTestConfig[T any]() T {
+	raw := config.GetConfig().Get("TEST_CONFIG")
+	return raw.(T)
+}
