@@ -16,21 +16,31 @@
  *
  */
 
-import React from 'react';
 import { Button, Intent, Position, IconName } from '@blueprintjs/core';
 import { Tooltip2 } from '@blueprintjs/popover2';
 
 interface Props {
-  icon: IconName;
+  style?: React.CSSProperties;
+  icon?: IconName;
+  image?: JSX.Element;
   tooltip: string;
   loading?: boolean;
+  disabled?: boolean;
   onClick?: () => void;
 }
 
-export const IconButton = ({ icon, tooltip, loading, onClick }: Props) => {
+export const IconButton = ({ style, icon, image, tooltip, loading, disabled, onClick }: Props) => {
   return (
     <Tooltip2 intent={Intent.PRIMARY} position={Position.TOP} content={tooltip}>
-      <Button loading={loading} minimal intent={Intent.PRIMARY} icon={icon} onClick={onClick} />
+      <Button
+        style={style}
+        loading={loading}
+        disabled={disabled}
+        minimal
+        intent={Intent.PRIMARY}
+        icon={icon ?? image}
+        onClick={onClick}
+      />
     </Tooltip2>
   );
 };
