@@ -23,4 +23,8 @@ export const Card = styled.div`
   background-color: #fff;
   box-shadow: 0px 2.4px 4.8px -0.8px rgba(0, 0, 0, 0.1), 0px 1.6px 8px rgba(0, 0, 0, 0.07);
   border-radius: 8px;
+
+  & + & {
+    margin-top: 24px;
+  }
 `;
