@@ -45,6 +45,8 @@ export const Header = styled.div`
   }
 `;
 
-export const Body = styled.div``;
+export const Body = styled.div`
+  margin: 24px;
+`;
 
 export const Footer = styled.div``;
