@@ -17,5 +17,7 @@
  */
 
 export * from './use-auto-refresh';
+export * from './use-connections';
 export * from './use-refresh-data';
+export * from './use-tips';
 export * from './user-proxy-prefix';
