@@ -82,14 +82,6 @@ export const Sider = styled.div`
   }
 `;
 
-export const Main = styled.div`
-  display: flex;
-  flex-direction: column;
-  flex: auto;
-  height: 100vh;
-  overflow: hidden;
-`;
-
 export const Header = styled(Navbar)`
   flex: 0 0 50px;
   background-color: #f9f9fa;
@@ -110,6 +102,14 @@ export const Header = styled(Navbar)`
   }
 `;
 
+export const Main = styled.div`
+  display: flex;
+  flex-direction: column;
+  flex: auto;
+  height: 100vh;
+  overflow: hidden;
+`;
+
 export const Inner = styled.div`
   flex: auto;
   margin-top: 24px;
@@ -124,6 +124,26 @@ export const Content = styled.div`
   min-width: 900px;
 `;
 
+export const Tips = styled.div`
+  display: flex;
+  align-items: center;
+  padding: 14px 0;
+  color: #fff;
+  background-color: #3c5088;
+
+  .content {
+    flex: auto;
+    display: flex;
+    align-items: center;
+    justify-content: center;
+  }
+
+  .bp4-popover2-target {
+    flex: 0 0 50px;
+    width: 50px;
+  }
+`;
+
 export const SiderMenuItem = styled.div`
   display: flex;
   align-items: center;
