@@ -17,19 +17,16 @@
  */
 
 import ReactDOM from 'react-dom';
-import { BrowserRouter } from 'react-router-dom';
 
-import { ErrorBoundary } from '@/error';
+import { ErrorBoundary } from '@/components';
 
 import App from './App';
 
 import './index.css';
 
 ReactDOM.render(
-  <BrowserRouter>
-    <ErrorBoundary>
-      <App />
-    </ErrorBoundary>
-  </BrowserRouter>,
+  <ErrorBoundary>
+    <App />
+  </ErrorBoundary>,
   document.getElementById('root'),
 );
