@@ -18,30 +18,24 @@
 
 import { useParams } from 'react-router-dom';
 
-import { PageHeader, PageLoading } from '@/components';
+import { PageHeader } from '@/components';
 
 import { FromEnum } from '../types';
 
-import { useDetail } from './use-detail';
 import { BlueprintDetail } from './blueprint-detail';
 
 export const BlueprintDetailPage = () => {
-  const { id } = useParams<{ id: string }>();
-
-  const { loading, blueprint } = useDetail({ id });
-
-  if (loading || !blueprint) {
-    return <PageLoading />;
-  }
+  const { id } = useParams() as { id: string };
 
   return (
     <PageHeader
       breadcrumbs={[
+        { name: 'Advanced', path: '/blueprints' },
         { name: 'Blueprints', path: '/blueprints' },
-        { name: blueprint.name, path: `/blueprints/${blueprint.id}` },
+        { name: id, path: `/blueprints/${id}` },
       ]}
     >
-      <BlueprintDetail from={FromEnum.blueprint} id={blueprint.id} />
+      <BlueprintDetail id={id} from={FromEnum.blueprint} />
     </PageHeader>
   );
 };
