@@ -22,11 +22,12 @@ export enum ModeEnum {
 }
 
 export enum FromEnum {
-  project = 'project',
-  blueprint = 'blueprint',
+  project = 'PROJECT',
+  blueprint = 'BLUEPRINT',
 }
 
 export type BlueprintType = {
+  projectName: string;
   id: ID;
   enable: boolean;
   name: string;
@@ -41,9 +42,8 @@ export type BlueprintType = {
     connections: Array<{
       plugin: string;
       connectionId: ID;
-      scopes: Array<{
+      scopes?: Array<{
         id: string;
-        entities: string[];
       }>;
     }>;
   };
