@@ -23,7 +23,15 @@ type GetProjectsParams = {
   pageSize: number;
 };
 
-export const getProjects = (params: GetProjectsParams) => request('/projects', { data: params });
+type GetProjectsResponse = {
+  projects: Array<{
+    name: string;
+  }>;
+  counts: number;
+};
+
+export const getProjects = (params: GetProjectsParams): Promise<GetProjectsResponse> =>
+  request('/projects', { data: params });
 
 type CreateProjectPayload = {
   name: string;
@@ -40,3 +48,9 @@ export const createProject = (payload: CreateProjectPayload) =>
     method: 'post',
     data: payload,
   });
+
+export const createBlueprint = (payload: any) =>
+  request('/blueprints', {
+    method: 'post',
+    data: payload,
+  });
