@@ -16,10 +16,11 @@
  *
  */
 
-import React, { useEffect, useState } from 'react';
-import { FormGroup, InputGroup, Button, Intent } from '@blueprintjs/core';
+import { useEffect, useState } from 'react';
+import { FormGroup, Button, Icon, Intent } from '@blueprintjs/core';
 
-import { ExternalLink } from '@/components';
+import { ExternalLink, FormPassword } from '@/components';
+import { DOC_URL } from '@/release';
 
 import * as API from '../api';
 
@@ -27,8 +28,9 @@ import * as S from './styled';
 
 type TokenItem = {
   value: string;
-  status: 'idle' | 'valid' | 'invalid';
+  isValid?: boolean;
   from?: string;
+  status?: 'success' | 'warning' | 'error';
 };
 
 interface Props {
@@ -42,31 +44,32 @@ interface Props {
 }
 
 export const Token = ({ endpoint, proxy, initialValue, value, error, setValue, setError }: Props) => {
-  const [tokens, setTokens] = useState<TokenItem[]>([{ value: '', status: 'idle' }]);
+  const [tokens, setTokens] = useState<TokenItem[]>([{ value: '' }]);
 
   const testToken = async (token: string): Promise<TokenItem> => {
     if (!endpoint || !token) {
       return {
         value: token,
-        status: 'idle',
       };
     }
 
     try {
       const res = await API.testConnection({
+        authMethod: 'AccessToken',
         endpoint,
         proxy,
         token,
       });
       return {
         value: token,
-        status: 'valid',
+        isValid: true,
         from: res.login,
+        status: !res.success ? 'error' : res.warning ? 'warning' : 'success',
       };
     } catch {
       return {
         value: token,
-        status: 'invalid',
+        isValid: false,
       };
     }
   };
@@ -82,22 +85,26 @@ export const Token = ({ endpoint, proxy, initialValue, value, error, setValue, s
 
   useEffect(() => {
     setError(value ? '' : 'token is required');
+
+    return () => {
+      setError('');
+    };
   }, [value]);
 
   useEffect(() => {
     setValue(tokens.map((it) => it.value).join(','));
   }, [tokens]);
 
-  const handleCreateToken = () => setTokens([...tokens, { value: '', status: 'idle' }]);
+  const handleCreateToken = () => setTokens([...tokens, { value: '' }]);
 
   const handleRemoveToken = (key: number) => setTokens(tokens.filter((_, i) => (i === key ? false : true)));
 
   const handleChangeToken = (key: number, value: string) =>
-    setTokens(tokens.map((it, i) => (i === key ? { value, status: 'idle' } : it)));
+    setTokens(tokens.map((it, i) => (i === key ? { value } : it)));
 
   const handleTestToken = async (key: number) => {
     const token = tokens.find((_, i) => i === key) as TokenItem;
-    if (token.status === 'idle' && token.value) {
+    if (token.isValid === undefined && token.value) {
       const res = await testToken(token.value);
       setTokens((tokens) => tokens.map((it, i) => (i === key ? res : it)));
     }
@@ -111,27 +118,50 @@ export const Token = ({ endpoint, proxy, initialValue, value, error, setValue, s
         <S.LabelDescription>
           Add one or more personal token(s) for authentication from you and your organization members. Multiple tokens
           (from different GitHub accounts, NOT from one account) can help speed up the data collection process.{' '}
-          <ExternalLink link="https://devlake.apache.org/docs/Configuration/GitHub/#auth-tokens">
+          <ExternalLink link={DOC_URL.PLUGIN.GITHUB.AUTH_TOKEN}>
             Learn how to create a personal access token
           </ExternalLink>
         </S.LabelDescription>
       }
     >
-      {tokens.map(({ value, status, from }, i) => (
-        <S.Token key={i}>
-          <InputGroup
-            placeholder="Token"
-            type="password"
-            value={value ?? ''}
-            onChange={(e) => handleChangeToken(i, e.target.value)}
-            onBlur={() => handleTestToken(i)}
-          />
-          <Button minimal icon="cross" onClick={() => handleRemoveToken(i)} />
-          <div className="info">
-            {status === 'invalid' && <span className="error">Invalid</span>}
-            {status === 'valid' && <span className="success">Valid From: {from}</span>}
+      {tokens.map(({ value, isValid, status, from }, i) => (
+        <S.Input key={i}>
+          <div className="input">
+            <FormPassword
+              placeholder="Token"
+              onChange={(e) => handleChangeToken(i, e.target.value)}
+              onBlur={() => handleTestToken(i)}
+            />
+            <Button minimal icon="cross" onClick={() => handleRemoveToken(i)} />
+            <div className="info">
+              {isValid === false && <span className="error">Invalid</span>}
+              {isValid === true && <span className="success">Valid From: {from}</span>}
+            </div>
           </div>
-        </S.Token>
+          {status && (
+            <S.Alert>
+              <h4>
+                {status === 'success' && <Icon icon="tick-circle" color="#4DB764" />}
+                {status === 'warning' && <Icon icon="warning-sign" color="#F4BE55" />}
+                {status === 'error' && <Icon icon="cross-circle" color="#E34040" />}
+                <span style={{ marginLeft: 8 }}>Token Permissions</span>
+              </h4>
+              {status === 'success' && <p>All required fields are checked.</p>}
+              {status === 'warning' && (
+                <p>
+                  This token is able to collect public repositories. If you want to collect private repositories, please
+                  check the field `repo`.
+                </p>
+              )}
+              {status === 'error' && (
+                <>
+                  <p>Please check the field(s) `repo:status`, `repo_deployment`, `read:user`, `read:org`.</p>
+                  <p>If you want to collect private repositories, please check the field `repo`.</p>
+                </>
+              )}
+            </S.Alert>
+          )}
+        </S.Input>
       ))}
       <div className="action">
         <Button outlined small intent={Intent.PRIMARY} text="Another Token" icon="plus" onClick={handleCreateToken} />
