@@ -18,9 +18,9 @@
 
 import { request } from '@/utils';
 
-export const getConnection = (plugin: string) => request(`/plugins/${plugin}/connections`);
-
-type TestConnectionPayload = {
+type GetConnectionRes = {
+  id: ID;
+  name: string;
   endpoint: string;
   proxy: string;
   token?: string;
@@ -29,6 +29,19 @@ type TestConnectionPayload = {
   authMethod?: string;
 };
 
+export const getConnection = (plugin: string): Promise<GetConnectionRes[]> => request(`/plugins/${plugin}/connections`);
+
+type TestConnectionPayload = {
+  endpoint: string;
+  proxy: string;
+  token?: string;
+  username?: string;
+  password?: string;
+  authMethod?: string;
+  appId?: string;
+  secretKey?: string;
+};
+
 export const testConnection = (plugin: string, data: TestConnectionPayload) =>
   request(`/plugins/${plugin}/test`, {
     method: 'post',
