@@ -18,36 +18,28 @@
 
 import type { AxiosRequestConfig } from 'axios';
 import axios from 'axios';
-import { history } from '@/utils/history';
 
 import { DEVLAKE_ENDPOINT } from '@/config';
-import { toast } from '@/components/toast';
 
 const instance = axios.create({
   baseURL: DEVLAKE_ENDPOINT,
 });
 
-const Errors = ['Authorization header is missing', 'Invalid token'];
-
 instance.interceptors.response.use(
   (response) => response,
   (error) => {
     const status = error.response?.status;
 
-    if (status === 401 && Errors.some((err) => error.response.data.includes(err))) {
-      toast.error('Please login first');
-      history.push('/login');
-    }
-
     if (status === 428) {
-      history.push('/db-migrate');
+      window.location.replace('/db-migrate');
     }
 
     return Promise.reject(error);
   },
 );
 
-export type ReuqestConfig = {
+export type RequestConfig = {
+  baseURL?: string;
   method?: AxiosRequestConfig['method'];
   data?: unknown;
   timeout?: number;
@@ -55,7 +47,7 @@ export type ReuqestConfig = {
   headers?: Record<string, string>;
 };
 
-export const request = (path: string, config?: ReuqestConfig) => {
+export const request = (path: string, config?: RequestConfig) => {
   const { method = 'get', data, timeout, headers, signal } = config || {};
 
   const cancelTokenSource = axios.CancelToken.source();
@@ -66,6 +58,7 @@ export const request = (path: string, config?: ReuqestConfig) => {
   }
 
   const params: any = {
+    baseURL: config?.baseURL,
     url: path,
     method,
     timeout,
